@@ -6,11 +6,11 @@
 #
 import atexit
 import datetime
+import inspect
 import math
 import re
 import threading
 import time
-
 from contextlib import suppress
 from decimal import Decimal
 from queue import Queue
@@ -18,48 +18,57 @@ from typing import Optional, Union
 from urllib.parse import urlparse
 from warnings import warn
 
+from pywikibot import config as _config
+from pywikibot import exceptions
 from pywikibot.__metadata__ import (
-    __copyright__, __description__, __download_url__, __license__,
-    __maintainer__, __maintainer_email__, __name__, __url__, __version__)
-
+    __copyright__,
+    __description__,
+    __download_url__,
+    __license__,
+    __maintainer__,
+    __maintainer_email__,
+    __name__,
+    __url__,
+    __version__,
+)
 from pywikibot._wbtypes import WbRepresentation as _WbRepresentation
 from pywikibot.backports import cache, removesuffix
 from pywikibot.bot import (
-    input, input_choice, input_yn, handle_args, show_help, ui,
-    calledModuleName, Bot, CurrentPageBot, WikidataBot,
+    Bot,
+    CurrentPageBot,
+    WikidataBot,
+    calledModuleName,
+    handle_args,
+    input,
+    input_choice,
+    input_yn,
+    show_help,
+    ui,
 )
-from pywikibot.bot_choice import (
-    QuitKeyboardInterrupt as _QuitKeyboardInterrupt,
-)
-from pywikibot import config2 as config
-from pywikibot.data.api import UploadWarning
 from pywikibot.diff import PatchManager
 from pywikibot.exceptions import (
-    BadTitle, CaptchaError, CascadeLockedPage, CircularRedirect,
-    CoordinateGlobeUnknownException, EditConflict, Error, FatalServerError,
-    InterwikiRedirectPage, InvalidTitle, IsNotRedirectPage, IsRedirectPage,
-    LockedNoPage, LockedPage, NoCreateError, NoMoveTarget, NoPage, NoSuchSite,
-    NoUsername, NoWikibaseEntity, OtherPageSaveError, PageCreatedConflict,
-    PageDeletedConflict, PageNotSaved, PageRelatedError, PageSaveRelatedError,
-    SectionError, Server414Error, Server504Error, ServerError,
-    SiteDefinitionError, SpamblacklistError, TitleblacklistError,
-    UnknownExtension, UnknownFamily, UnknownSite, UnsupportedPage,
-    WikiBaseError,
+    DEPRECATED_EXCEPTIONS,
+    CoordinateGlobeUnknownError,
 )
 from pywikibot.family import AutoFamily, Family
 from pywikibot.i18n import translate
 from pywikibot.logging import (
-    critical, debug, error, exception, log, output, stdout, warning
+    critical,
+    debug,
+    error,
+    exception,
+    log,
+    output,
+    stdout,
+    warning,
 )
-from pywikibot.site import BaseSite, DataSite, APISite, ClosedSite
+from pywikibot.site import APISite, BaseSite, ClosedSite, DataSite
 from pywikibot.tools import (
-    classproperty,
-    deprecate_arg as _deprecate_arg,
-    normalize_username,
-    MediaWikiVersion as _MediaWikiVersion,
     ModuleDeprecationWrapper as _ModuleDeprecationWrapper,
-    redirect_func,
 )
+from pywikibot.tools import classproperty
+from pywikibot.tools import deprecate_arg as _deprecate_arg
+from pywikibot.tools import normalize_username
 from pywikibot.tools.formatter import color_format
 
 
@@ -67,20 +76,19 @@ __all__ = (
     '__copyright__', '__description__', '__download_url__', '__license__',
     '__maintainer__', '__maintainer_email__', '__name__',
     '__url__', '__version__',
-    'BadTitle', 'Bot', 'calledModuleName', 'CaptchaError', 'CascadeLockedPage',
-    'Category', 'CircularRedirect', 'Claim', 'config', 'Coordinate',
+    'Bot', 'calledModuleName', 'CaptchaError', 'CascadeLockedPage',
+    'Category', 'CircularRedirect', 'Claim', 'Coordinate',
     'CoordinateGlobeUnknownException', 'critical', 'CurrentPageBot', 'debug',
     'EditConflict', 'error', 'Error', 'exception', 'FatalServerError',
-    'FilePage', 'handle_args', 'html2unicode', 'input',
-    'input_choice', 'input_yn', 'InterwikiRedirectPage', 'InvalidTitle',
-    'IsNotRedirectPage', 'IsRedirectPage', 'ItemPage', 'Link', 'LockedNoPage',
-    'LockedPage', 'log', 'NoCreateError', 'NoMoveTarget', 'NoPage',
-    'NoSuchSite', 'NoUsername', 'NoWikibaseEntity', 'OtherPageSaveError',
-    'output', 'Page', 'PageCreatedConflict', 'PageDeletedConflict',
-    'PageNotSaved', 'PageRelatedError', 'PageSaveRelatedError', 'PropertyPage',
-    '_QuitKeyboardInterrupt', 'SectionError', 'Server414Error',
-    'Server504Error', 'ServerError', 'showDiff', 'show_help',
-    'Site', 'SiteDefinitionError', 'SiteLink', 'SpamblacklistError', 'stdout',
+    'FilePage', 'handle_args', 'html2unicode', 'input', 'input_choice',
+    'input_yn', 'InterwikiRedirectPage', 'InvalidTitle', 'IsNotRedirectPage',
+    'IsRedirectPage', 'ItemPage', 'Link', 'LockedNoPage', 'LockedPage', 'log',
+    'NoCreateError', 'NoMoveTarget', 'NoPage', 'NoUsername',
+    'NoWikibaseEntity', 'OtherPageSaveError', 'output', 'Page',
+    'PageCreatedConflict', 'PageDeletedConflict', 'PageRelatedError',
+    'PageSaveRelatedError', 'PropertyPage', 'SectionError', 'Server414Error',
+    'Server504Error', 'ServerError', 'showDiff', 'show_help', 'Site',
+    'SiteDefinitionError', 'SiteLink', 'SpamblacklistError', 'stdout',
     'Timestamp', 'TitleblacklistError', 'translate', 'ui', 'unicode2html',
     'UnknownExtension', 'UnknownFamily', 'UnknownSite', 'UnsupportedPage',
     'UploadWarning', 'url2unicode', 'User', 'warning', 'WbGeoShape',
@@ -125,21 +133,21 @@ class Timestamp(datetime.datetime):
     def _ISO8601Format(cls, sep: str = 'T') -> str:
         """ISO8601 format string.
 
-        @param sep: one-character separator, placed between the date and time
-        @return: ISO8601 format string
+        :param sep: one-character separator, placed between the date and time
+        :return: ISO8601 format string
         """
-        assert(len(sep) == 1)
-        return '%Y-%m-%d{0}%H:%M:%SZ'.format(sep)
+        assert len(sep) == 1
+        return '%Y-%m-%d{}%H:%M:%SZ'.format(sep)
 
     @classmethod
     def fromISOformat(cls, ts, sep: str = 'T'):
         """Convert an ISO 8601 timestamp to a Timestamp object.
 
-        @param ts: ISO 8601 timestamp or a Timestamp object already
-        @type ts: str or Timestamp
-        @param sep: one-character separator, placed between the date and time
-        @return: Timestamp object
-        @rtype: Timestamp
+        :param ts: ISO 8601 timestamp or a Timestamp object already
+        :type ts: str or Timestamp
+        :param sep: one-character separator, placed between the date and time
+        :return: Timestamp object
+        :rtype: Timestamp
         """
         # If inadvertently passed a Timestamp object, use replace()
         # to create a clone.
@@ -211,20 +219,20 @@ class Coordinate(_WbRepresentation):
         """
         Represent a geo coordinate.
 
-        @param lat: Latitude
-        @param lon: Longitude
-        @param alt: Altitude? TODO FIXME
-        @param precision: precision
-        @param globe: Which globe the point is on
-        @param typ: The type of coordinate point
-        @param name: The name
-        @param dim: Dimension (in meters)
-        @param site: The Wikibase site
-        @param globe_item: The Wikibase item for the globe, or the entity URI
+        :param lat: Latitude
+        :param lon: Longitude
+        :param alt: Altitude? TODO FIXME
+        :param precision: precision
+        :param globe: Which globe the point is on
+        :param typ: The type of coordinate point
+        :param name: The name
+        :param dim: Dimension (in meters)
+        :param site: The Wikibase site
+        :param globe_item: The Wikibase item for the globe, or the entity URI
                            of this Wikibase item. Takes precedence over 'globe'
                            if present.
-        @type globe_item: pywikibot.ItemPage or str
-        @param primary: True for a primary set of coordinates
+        :type globe_item: pywikibot.ItemPage or str
+        :param primary: True for a primary set of coordinates
         """
         self.lat = lat
         self.lon = lon
@@ -248,9 +256,9 @@ class Coordinate(_WbRepresentation):
         """Return the entity uri of the globe."""
         if not self._entity:
             if self.globe not in self.site.globes():
-                raise CoordinateGlobeUnknownException(
-                    '%s is not supported in Wikibase yet.'
-                    % self.globe)
+                raise CoordinateGlobeUnknownError(
+                    '{} is not supported in Wikibase yet.'
+                    .format(self.globe))
             return self.site.globes()[self.globe]
 
         if isinstance(self._entity, ItemPage):
@@ -264,7 +272,7 @@ class Coordinate(_WbRepresentation):
 
         FIXME: Should this be in the DataSite object?
 
-        @return: Wikibase JSON
+        :return: Wikibase JSON
         """
         return {'latitude': self.lat,
                 'longitude': self.lon,
@@ -278,9 +286,9 @@ class Coordinate(_WbRepresentation):
         """
         Constructor to create an object from Wikibase's JSON output.
 
-        @param data: Wikibase JSON
-        @param site: The Wikibase site
-        @rtype: Coordinate
+        :param data: Wikibase JSON
+        :param site: The Wikibase site
+        :rtype: Coordinate
         """
         globe = None
 
@@ -382,10 +390,10 @@ class Coordinate(_WbRepresentation):
         A successful lookup is stored as an internal value to avoid the need
         for repeated lookups.
 
-        @param repo: the Wikibase site for the globe, if different from that
+        :param repo: the Wikibase site for the globe, if different from that
             provided with the Coordinate.
-        @param lazy_load: Do not raise NoPage if ItemPage does not exist.
-        @return: pywikibot.ItemPage
+        :param lazy_load: Do not raise NoPage if ItemPage does not exist.
+        :return: pywikibot.ItemPage
         """
         if isinstance(self._entity, ItemPage):
             return self._entity
@@ -450,20 +458,20 @@ class WbTime(_WbRepresentation):
           of the event, in the range −180° to 180°, multiplied by 4 to convert
           to minutes.
 
-        @param year: The year as a signed integer of between 1 and 16 digits.
-        @param month: Month
-        @param day: Day
-        @param hour: Hour
-        @param minute: Minute
-        @param second: Second
-        @param precision: The unit of the precision of the time.
-        @param before: Number of units after the given time it could be, if
+        :param year: The year as a signed integer of between 1 and 16 digits.
+        :param month: Month
+        :param day: Day
+        :param hour: Hour
+        :param minute: Minute
+        :param second: Second
+        :param precision: The unit of the precision of the time.
+        :param before: Number of units after the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param after: Number of units before the given time it could be, if
+        :param after: Number of units before the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param timezone: Timezone information in minutes.
-        @param calendarmodel: URI identifying the calendar model
-        @param site: The Wikibase site
+        :param timezone: Timezone information in minutes.
+        :param calendarmodel: URI identifying the calendar model
+        :param site: The Wikibase site
         """
         if year is None:
             raise ValueError('no year given')
@@ -496,7 +504,8 @@ class WbTime(_WbRepresentation):
             if site is None:
                 site = Site().data_repository()
                 if site is None:
-                    raise ValueError('Site %s has no data repository' % Site())
+                    raise ValueError('Site {} has no data repository'
+                                     .format(Site()))
             calendarmodel = site.calendarmodel()
         self.calendarmodel = calendarmodel
 
@@ -508,7 +517,7 @@ class WbTime(_WbRepresentation):
             elif precision in self.PRECISION:
                 self.precision = self.PRECISION[precision]
             else:
-                raise ValueError('Invalid precision: "%s"' % precision)
+                raise ValueError('Invalid precision: "{}"'.format(precision))
 
     @classmethod
     def fromTimestr(cls,
@@ -528,22 +537,22 @@ class WbTime(_WbRepresentation):
         * The Z is discarded since time zone is determined from the timezone
           param.
 
-        @param datetimestr: Timestamp in a format resembling ISO 8601,
+        :param datetimestr: Timestamp in a format resembling ISO 8601,
             e.g. +2013-01-01T00:00:00Z
-        @param precision: The unit of the precision of the time.
-        @param before: Number of units after the given time it could be, if
+        :param precision: The unit of the precision of the time.
+        :param before: Number of units after the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param after: Number of units before the given time it could be, if
+        :param after: Number of units before the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param timezone: Timezone information in minutes.
-        @param calendarmodel: URI identifying the calendar model
-        @param site: The Wikibase site
-        @rtype: pywikibot.WbTime
+        :param timezone: Timezone information in minutes.
+        :param calendarmodel: URI identifying the calendar model
+        :param site: The Wikibase site
+        :rtype: pywikibot.WbTime
         """
         match = re.match(r'([-+]?\d+)-(\d+)-(\d+)T(\d+):(\d+):(\d+)Z',
                          datetimestr)
         if not match:
-            raise ValueError("Invalid format: '%s'" % datetimestr)
+            raise ValueError("Invalid format: '{}'".format(datetimestr))
         t = match.groups()
         return cls(int(t[0]), int(t[1]), int(t[2]),
                    int(t[3]), int(t[4]), int(t[5]),
@@ -557,17 +566,17 @@ class WbTime(_WbRepresentation):
         """
         Create a new WbTime object from a pywikibot.Timestamp.
 
-        @param timestamp: Timestamp
-        @type timestamp: pywikibot.Timestamp
-        @param precision: The unit of the precision of the time.
-        @param before: Number of units after the given time it could be, if
+        :param timestamp: Timestamp
+        :type timestamp: pywikibot.Timestamp
+        :param precision: The unit of the precision of the time.
+        :param before: Number of units after the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param after: Number of units before the given time it could be, if
+        :param after: Number of units before the given time it could be, if
             uncertain. The unit is given by the precision.
-        @param timezone: Timezone information in minutes.
-        @param calendarmodel: URI identifying the calendar model
-        @param site: The Wikibase site
-        @rtype: pywikibot.WbTime
+        :param timezone: Timezone information in minutes.
+        :param calendarmodel: URI identifying the calendar model
+        :param site: The Wikibase site
+        :rtype: pywikibot.WbTime
         """
         return cls.fromTimestr(timestamp.isoformat(), precision=precision,
                                before=before, after=after,
@@ -581,8 +590,8 @@ class WbTime(_WbRepresentation):
         See fromTimestr() for differences between output with and without
         force_iso.
 
-        @param force_iso: whether the output should be forced to ISO 8601
-        @return: Timestamp in a format resembling ISO 8601
+        :param force_iso: whether the output should be forced to ISO 8601
+        :return: Timestamp in a format resembling ISO 8601
         """
         if force_iso:
             return Timestamp._ISO8601Format_new.format(
@@ -595,7 +604,7 @@ class WbTime(_WbRepresentation):
         """
         Convert the data to a pywikibot.Timestamp.
 
-        @raises ValueError: instance value cannot be represented using
+        :raises ValueError: instance value cannot be represented using
             Timestamp
         """
         if self.year <= 0:
@@ -607,7 +616,7 @@ class WbTime(_WbRepresentation):
         """
         Convert the data to a JSON object for the Wikibase API.
 
-        @return: Wikibase JSON
+        :return: Wikibase JSON
         """
         json = {'time': self.toTimestr(),
                 'precision': self.precision,
@@ -623,9 +632,9 @@ class WbTime(_WbRepresentation):
         """
         Create a WbTime from the JSON data given by the Wikibase API.
 
-        @param wb: Wikibase JSON
-        @param site: The Wikibase site
-        @rtype: pywikibot.WbTime
+        :param wb: Wikibase JSON
+        :param site: The Wikibase site
+        :rtype: pywikibot.WbTime
         """
         return cls.fromTimestr(wb['time'], wb['precision'],
                                wb['before'], wb['after'],
@@ -645,7 +654,7 @@ class WbQuantity(_WbRepresentation):
 
         If no site item is supplied it raises a warning and returns True.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         if not site:
             warning(
@@ -661,7 +670,7 @@ class WbQuantity(_WbRepresentation):
 
         None value is returned as is.
 
-        @param value: decimal number to convert
+        :param value: decimal number to convert
         """
         if isinstance(value, Decimal):
             return value
@@ -676,7 +685,7 @@ class WbQuantity(_WbRepresentation):
 
         None value is returned as is.
 
-        @param value: decimal number to convert
+        :param value: decimal number to convert
         """
         if value is None:
             return None
@@ -687,16 +696,16 @@ class WbQuantity(_WbRepresentation):
         """
         Create a new WbQuantity object.
 
-        @param amount: number representing this quantity
-        @type amount: str or Decimal. Other types are accepted, and
+        :param amount: number representing this quantity
+        :type amount: str or Decimal. Other types are accepted, and
             converted via str to Decimal.
-        @param unit: the Wikibase item for the unit or the entity URI of this
+        :param unit: the Wikibase item for the unit or the entity URI of this
             Wikibase item.
-        @type unit: pywikibot.ItemPage, str or None
-        @param error: the uncertainty of the amount (e.g. ±1)
-        @type error: same as amount, or tuple of two values, where the first
+        :type unit: pywikibot.ItemPage, str or None
+        :param error: the uncertainty of the amount (e.g. ±1)
+        :type error: same as amount, or tuple of two values, where the first
             value is the upper error and the second is the lower error value.
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         if amount is None:
             raise ValueError('no amount given')
@@ -742,10 +751,10 @@ class WbQuantity(_WbRepresentation):
         A successful lookup is stored as an internal value to avoid the need
         for repeated lookups.
 
-        @param repo: the Wikibase site for the unit, if different from that
+        :param repo: the Wikibase site for the unit, if different from that
             provided with the WbQuantity.
-        @param lazy_load: Do not raise NoPage if ItemPage does not exist.
-        @return: pywikibot.ItemPage
+        :param lazy_load: Do not raise NoPage if ItemPage does not exist.
+        :return: pywikibot.ItemPage
         """
         if not isinstance(self._unit, str):
             return self._unit
@@ -758,7 +767,7 @@ class WbQuantity(_WbRepresentation):
         """
         Convert the data to a JSON object for the Wikibase API.
 
-        @return: Wikibase JSON
+        :return: Wikibase JSON
         """
         json = {'amount': self._fromdecimal(self.amount),
                 'upperBound': self._fromdecimal(self.upperBound),
@@ -772,9 +781,9 @@ class WbQuantity(_WbRepresentation):
         """
         Create a WbQuantity from the JSON data given by the Wikibase API.
 
-        @param wb: Wikibase JSON
-        @param site: The Wikibase site
-        @rtype: pywikibot.WbQuantity
+        :param wb: Wikibase JSON
+        :param site: The Wikibase site
+        :rtype: pywikibot.WbQuantity
         """
         amount = cls._todecimal(wb['amount'])
         upperBound = cls._todecimal(wb.get('upperBound'))
@@ -799,8 +808,8 @@ class WbMonolingualText(_WbRepresentation):
         """
         Create a new WbMonolingualText object.
 
-        @param text: text string
-        @param language: language code of the string
+        :param text: text string
+        :param language: language code of the string
         """
         if not text or not language:
             raise ValueError('text and language cannot be empty')
@@ -811,7 +820,7 @@ class WbMonolingualText(_WbRepresentation):
         """
         Convert the data to a JSON object for the Wikibase API.
 
-        @return: Wikibase JSON
+        :return: Wikibase JSON
         """
         json = {'text': self.text,
                 'language': self.language
@@ -823,8 +832,8 @@ class WbMonolingualText(_WbRepresentation):
         """
         Create a WbMonolingualText from the JSON data given by Wikibase API.
 
-        @param wb: Wikibase JSON
-        @rtype: pywikibot.WbMonolingualText
+        :param wb: Wikibase JSON
+        :rtype: pywikibot.WbMonolingualText
         """
         return cls(wb['text'], wb['language'])
 
@@ -847,7 +856,7 @@ class _WbDataPage(_WbRepresentation):
 
         Must be implemented in the extended class.
 
-        @param repo_site: The Wikibase site
+        :param repo_site: The Wikibase site
         """
         raise NotImplementedError
 
@@ -865,7 +874,7 @@ class _WbDataPage(_WbRepresentation):
         * data_site: APISite, site serving as a repository for
             the given data type.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         raise NotImplementedError
 
@@ -874,14 +883,14 @@ class _WbDataPage(_WbRepresentation):
         """
         Validate the provided page against general and type specific rules.
 
-        @param page: Page containing the data.
-        @type page: pywikibot.Page
-        @param data_site: The site serving as a repository for the given
+        :param page: Page containing the data.
+        :type page: pywikibot.Page
+        :param data_site: The site serving as a repository for the given
             data type.
-        @type data_site: APISite
-        @param ending: Required filetype-like ending in page titles.
+        :type data_site: APISite
+        :param ending: Required filetype-like ending in page titles.
             E.g. '.map'
-        @param label: Label describing the data type in error messages.
+        :param label: Label describing the data type in error messages.
         """
         if not isinstance(page, Page):
             raise ValueError(
@@ -895,10 +904,10 @@ class _WbDataPage(_WbRepresentation):
         # validate page is on the right site, and that site supports the type
         if not data_site:
             raise ValueError(
-                'The provided site does not support {0}.'.format(label))
+                'The provided site does not support {}.'.format(label))
         if page.site != data_site:
             raise ValueError(
-                'Page must be on the {0} repository site.'.format(label))
+                'Page must be on the {} repository site.'.format(label))
 
         # validate page title fulfills hard-coded Wikibase requirement
         # pcre regexp: '/^Data:[^\\[\\]#\\\:{|}]+\.map$/u' for geo-shape
@@ -908,16 +917,16 @@ class _WbDataPage(_WbRepresentation):
         if not page.title().startswith('Data:') \
            or not page.title().endswith(ending):
             raise ValueError(
-                "Page must be in 'Data:' namespace and end in '{0}' "
-                'for {1}.'.format(ending, label))
+                "Page must be in 'Data:' namespace and end in '{}' "
+                'for {}.'.format(ending, label))
 
     def __init__(self, page, site: Optional[DataSite] = None):
         """
         Create a new _WbDataPage object.
 
-        @param page: page containing the data
-        @type page: pywikibot.Page
-        @param site: The Wikibase site
+        :param page: page containing the data
+        :type page: pywikibot.Page
+        :param site: The Wikibase site
         """
         site = site or Site().data_repository()
         specifics = type(self)._get_type_specifics(site)
@@ -933,7 +942,7 @@ class _WbDataPage(_WbRepresentation):
         """
         Convert the data to the value required by the Wikibase API.
 
-        @return: title of the data page incl. namespace
+        :return: title of the data page incl. namespace
         """
         return self.page.title()
 
@@ -942,9 +951,9 @@ class _WbDataPage(_WbRepresentation):
         """
         Create a _WbDataPage from the JSON data given by the Wikibase API.
 
-        @param page_name: page name from Wikibase value
-        @param site: The Wikibase site
-        @rtype: pywikibot._WbDataPage
+        :param page_name: page name from Wikibase value
+        :param site: The Wikibase site
+        :rtype: pywikibot._WbDataPage
         """
         data_site = cls._get_data_site(site)
         page = Page(data_site, page_name)
@@ -959,7 +968,7 @@ class WbGeoShape(_WbDataPage):
         """
         Return the site serving as a geo-shape repository.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         return site.geo_shape_repository()
 
@@ -968,7 +977,7 @@ class WbGeoShape(_WbDataPage):
         """
         Return the specifics for WbGeoShape.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         specifics = {
             'ending': '.map',
@@ -986,7 +995,7 @@ class WbTabularData(_WbDataPage):
         """
         Return the site serving as a tabular-data repository.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         return site.tabular_data_repository()
 
@@ -995,7 +1004,7 @@ class WbTabularData(_WbDataPage):
         """
         Return the specifics for WbTabularData.
 
-        @param site: The Wikibase site
+        :param site: The Wikibase site
         """
         specifics = {
             'ending': '.tab',
@@ -1013,6 +1022,8 @@ class WbUnknown(_WbRepresentation):
     is introduced.
 
     This data type is just a json container
+
+    *New in version 3.0.*
     """
 
     _items = ('json',)
@@ -1021,7 +1032,7 @@ class WbUnknown(_WbRepresentation):
         """
         Create a new WbUnknown object.
 
-        @param json: Wikibase JSON
+        :param json: Wikibase JSON
         """
         self.json = json
 
@@ -1029,7 +1040,7 @@ class WbUnknown(_WbRepresentation):
         """
         Return the JSON object for the Wikibase API.
 
-        @return: Wikibase JSON
+        :return: Wikibase JSON
         """
         return self.json
 
@@ -1038,8 +1049,8 @@ class WbUnknown(_WbRepresentation):
         """
         Create a WbUnknown from the JSON data given by the Wikibase API.
 
-        @param json: Wikibase JSON
-        @rtype: pywikibot.WbUnknown
+        :param json: Wikibase JSON
+        :rtype: pywikibot.WbUnknown
         """
         return cls(json)
 
@@ -1052,13 +1063,13 @@ def _code_fam_from_url(url: str, name: Optional[str] = None):
     """Set url to cache and get code and family from cache.
 
     Site helper method.
-    @param url: The site URL to get code and family
-    @param name: A family name used by AutoFamily
+    :param url: The site URL to get code and family
+    :param name: A family name used by AutoFamily
     """
     matched_sites = []
     # Iterate through all families and look, which does apply to
     # the given URL
-    for fam in config.family_files:
+    for fam in _config.family_files:
         family = Family.load(fam)
         code = family.from_url(url)
         if code is not None:
@@ -1077,7 +1088,7 @@ def _code_fam_from_url(url: str, name: Optional[str] = None):
     return matched_sites[0]
 
 
-@_deprecate_arg('sysop', None)
+@_deprecate_arg('sysop', True)
 def Site(code: Optional[str] = None, fam=None, user: Optional[str] = None, *,
          interface=None,
          url: Optional[str] = None) -> Union[APISite, DataSite, ClosedSite]:
@@ -1088,18 +1099,55 @@ def Site(code: Optional[str] = None, fam=None, user: Optional[str] = None, *,
     By default rely on config settings. These defaults may all be overridden
     using the method parameters.
 
-    @param code: language code (override config.mylang)
+    Creating the default site using config.mylang and config.family::
+
+        site = pywikibot.Site()
+
+    Override default site code::
+
+        site = pywikibot.Site('fr')
+
+    Override default family::
+
+        site = pywikibot.Site(family='wikisource')
+
+    Setting a specific site::
+
+        site = pywikibot.Site('fr', 'wikisource')
+
+    which is equal to::
+
+        site = pywikibot.Site('wikisource:fr')
+
+    :Note: An already created site is cached an a new variable points to
+        the same object if interface, family, code and user are equal:
+
+    >>> import pywikibot
+    >>> site_1 = pywikibot.Site('wikisource:fr')
+    >>> site_2 = pywikibot.Site('fr', 'wikisource')
+    >>> site_1 is site_2
+    True
+    >>> site_1
+    APISite("fr", "wikisource")
+
+    ``APISite`` is the default interface. Refer :py:obj:`pywikibot.site` for
+    other interface types.
+
+    **Never create a site object via interface class directly.**
+    Always use this factory method.
+
+    :param code: language code (override config.mylang)
         code may also be a sitename like 'wikipedia:test'
-    @param fam: family name or object (override config.family)
-    @type fam: str or pywikibot.family.Family
-    @param user: bot user name to use on this site (override config.usernames)
-    @param interface: site class or name of class in pywikibot.site
+    :param fam: family name or object (override config.family)
+    :type fam: str or pywikibot.family.Family
+    :param user: bot user name to use on this site (override config.usernames)
+    :param interface: site class or name of class in :py:obj:`pywikibot.site`
         (override config.site_interface)
-    @type interface: subclass of L{pywikibot.site.BaseSite} or string
-    @param url: Instead of code and fam, does try to get a Site based on the
+    :type interface: subclass of :py:obj:`pywikibot.site.BaseSite` or string
+    :param url: Instead of code and fam, does try to get a Site based on the
         URL. Still requires that the family supporting that URL exists.
-    @raises ValueError: URL and pair of code and family given
-    @raises ValueError: Invalid interface name
+    :raises ValueError: URL and pair of code and family given
+    :raises ValueError: Invalid interface name
     """
     _logger = 'wiki'
 
@@ -1118,8 +1166,8 @@ def Site(code: Optional[str] = None, fam=None, user: Optional[str] = None, *,
         fam, _, code = code.partition(':')
     else:
         # Fallback to config defaults
-        code = code or config.mylang
-        fam = fam or config.family
+        code = code or _config.mylang
+        fam = fam or _config.family
 
     if not isinstance(fam, Family):
         fam = Family.load(fam)
@@ -1130,9 +1178,9 @@ def Site(code: Optional[str] = None, fam=None, user: Optional[str] = None, *,
     family_name = str(fam)
 
     code_to_user = {}
-    if '*' in config.usernames:  # T253127: usernames is a defaultdict
-        code_to_user = config.usernames['*'].copy()
-    code_to_user.update(config.usernames[family_name])
+    if '*' in _config.usernames:  # T253127: usernames is a defaultdict
+        code_to_user = _config.usernames['*'].copy()
+    code_to_user.update(_config.usernames[family_name])
     user = user or code_to_user.get(code) or code_to_user.get('*')
 
     if not isinstance(interface, type):
@@ -1140,46 +1188,41 @@ def Site(code: Optional[str] = None, fam=None, user: Optional[str] = None, *,
         try:
             tmp = __import__('pywikibot.site', fromlist=[interface])
         except ImportError:
-            raise ValueError('Invalid interface name: {0}'.format(interface))
+            raise ValueError('Invalid interface name: {}'.format(interface))
         else:
             interface = getattr(tmp, interface)
 
     if not issubclass(interface, BaseSite):
-        warning('Site called with interface=%s' % interface.__name__)
+        warning('Site called with interface={}'.format(interface.__name__))
 
     user = normalize_username(user)
-    key = '%s:%s:%s:%s' % (interface.__name__, fam, code, user)
+    key = '{}:{}:{}:{}'.format(interface.__name__, fam, code, user)
     if key not in _sites or not isinstance(_sites[key], interface):
         _sites[key] = interface(code=code, fam=fam, user=user)
-        debug("Instantiated %s object '%s'"
-              % (interface.__name__, _sites[key]), _logger)
+        debug("Instantiated {} object '{}'"
+              .format(interface.__name__, _sites[key]), _logger)
 
         if _sites[key].code != code:
-            warn('Site %s instantiated using different code "%s"'
-                 % (_sites[key], code), UserWarning, 2)
+            warn('Site {} instantiated using different code "{}"'
+                 .format(_sites[key], code), UserWarning, 2)
 
     return _sites[key]
 
 
-# alias for backwards-compability
-getSite = redirect_func(Site, old_name='getSite', since='20150924',
-                        future_warning=True)
-
-
 # These imports depend on Wb* classes above.
 from pywikibot.page import (  # noqa: E402
-    Page,
-    FilePage,
     Category,
+    Claim,
+    FilePage,
+    ItemPage,
     Link,
+    Page,
+    PropertyPage,
     SiteLink,
     User,
-    ItemPage,
-    PropertyPage,
-    Claim,
+    html2unicode,
+    url2unicode,
 )
-from pywikibot.page import (  # noqa: E402
-    html2unicode, url2unicode, unicode2html)
 
 
 link_regex = re.compile(r'\[\[(?P<title>[^\]|[<>{}]*)(\|.*?)?\]\]')
@@ -1239,7 +1282,7 @@ def _flush(stop=True):
             remainingPages -= 1
 
         remainingSeconds = datetime.timedelta(
-            seconds=round(remainingPages * config.put_throttle))
+            seconds=round(remainingPages * _config.put_throttle))
         return (remainingPages, remainingSeconds)
 
     if stop:
@@ -1247,7 +1290,7 @@ def _flush(stop=True):
         page_put_queue.put((None, [], {}))
 
     num, sec = remaining()
-    if num > 0 and sec.total_seconds() > config.noisysleep:
+    if num > 0 and sec.total_seconds() > _config.noisysleep:
         output(color_format(
             '{lightblue}Waiting for {num} pages to be put. '
             'Estimated time remaining: {sec}{default}', num=num, sec=sec))
@@ -1263,6 +1306,11 @@ def _flush(stop=True):
                             'Estimated time remaining: {}\nReally exit?'
                             .format(*remaining()),
                             default=False, automatic_quit=False):
+                    # delete the put queue
+                    with page_put_queue.mutex:
+                        page_put_queue.all_tasks_done.notify_all()
+                        page_put_queue.queue.clear()
+                        page_put_queue.not_full.notify_all()
                     break
 
     # only need one drop() call because all throttles use the same global pid
@@ -1290,19 +1338,15 @@ def async_manager():
 def async_request(request, *args, **kwargs):
     """Put a request on the queue, and start the daemon if necessary."""
     if not _putthread.is_alive():
-        try:
-            page_put_queue.mutex.acquire()
-            with suppress(AssertionError, RuntimeError):
-                _putthread.start()
-        finally:
-            page_put_queue.mutex.release()
+        with page_put_queue.mutex, suppress(AssertionError, RuntimeError):
+            _putthread.start()
     page_put_queue.put((request, args, kwargs))
 
 
 # queue to hold pending requests
-page_put_queue = Queue(config.max_queue_size)
+page_put_queue = Queue(_config.max_queue_size)
 # queue to signal that async_manager is working on a request. See T147178.
-page_put_queue_busy = Queue(config.max_queue_size)
+page_put_queue_busy = Queue(_config.max_queue_size)
 # set up the background thread
 _putthread = threading.Thread(target=async_manager)
 # identification for debugging purposes
@@ -1310,18 +1354,39 @@ _putthread.setName('Put-Thread')
 _putthread.setDaemon(True)
 
 wrapper = _ModuleDeprecationWrapper(__name__)
-wrapper._add_deprecated_attr(
-    'QuitKeyboardInterrupt', _QuitKeyboardInterrupt,
-    warning_message='pywikibot.QuitKeyboardInterrupt is deprecated; '
-                    'use pywikibot.bot.QuitKeyboardInterrupt instead.',
-    since='20150619', future_warning=True)
-wrapper._add_deprecated_attr(
-    'MediaWikiVersion', _MediaWikiVersion,
-    warning_message='pywikibot.MediaWikiVersion is deprecated; '
-                    'use pywikibot.tools.MediaWikiVersion instead.',
-    since='20180827')
-wrapper._add_deprecated_attr('__release__', __version__,
-                             replacement_name='pywikibot.__version__',
-                             since='20200707')
-wrapper._add_deprecated_attr('showHelp', show_help,
-                             since='20200705', future_warning=True)
+wrapper.add_deprecated_attr('config2', replacement_name='pywikibot.config',
+                            since='20210426')
+wrapper.add_deprecated_attr('__release__', __version__,
+                            replacement_name='pywikibot.__version__',
+                            since='20200707')
+wrapper.add_deprecated_attr('showHelp', show_help,
+                            since='20200705')
+wrapper.add_deprecated_attr(
+    'unicode2html', replacement_name='pywikibot.tools.chars.string2html',
+    since='6.2.0')
+
+# This module aliases many (but not all) pywikibot.exception classes and one
+# from pywikibot.data.api. Use of these aliases is deprecated. When removed
+# we can drop them from both our import and __all__ listing.
+
+EXCEPTION_CLASSES = {
+    n for n, _ in inspect.getmembers(exceptions, inspect.isclass)
+}
+
+EXCEPTION_CLASSES.add('UploadWarning')
+EXCEPTION_CLASSES.update(DEPRECATED_EXCEPTIONS.keys())
+
+for name in __all__:
+    if name in EXCEPTION_CLASSES:
+        if name in DEPRECATED_EXCEPTIONS:
+            replacement = DEPRECATED_EXCEPTIONS[name]
+        elif name == 'UploadWarning':
+            replacement = 'UploadError'
+        else:
+            replacement = name
+
+        wrapper.add_deprecated_attr(
+            name,
+            replacement_name='pywikibot.exceptions.{}'.format(replacement),
+            since='20210424'
+        )
