@@ -1,18 +1,24 @@
-"""Pywikibot metadata file."""
+"""Pywikibot metadata file.
+
+*New in version 4.0.*
+"""
 #
 # (C) Pywikibot team, 2020-2021
 #
 # Distributed under the terms of the MIT license.
 #
+from time import strftime
+
+
 __name__ = 'pywikibot'
-__version__ = '6.0.1'
+__version__ = '6.4.0'
 __description__ = 'Python MediaWiki Bot Framework'
 __maintainer__ = 'The Pywikibot team'
 __maintainer_email__ = 'pywikibot@lists.wikimedia.org'
 __license__ = 'MIT License'
 __url__ = 'https://www.mediawiki.org/wiki/Manual:Pywikibot'
 __download_url__ = 'https://pywikibot.toolforge.org/'
-__copyright__ = '(C) Pywikibot team, 2003-2021'
+__copyright__ = '(C) Pywikibot team, 2003-' + strftime('%Y')
 __keywords__ = 'API bot client framework mediawiki pwb pybot python pywiki ' \
                'pywikibase pywikibot pywikipedia pywikipediabot wiki ' \
                'wikibase wikidata wikimedia wikipedia'
