@@ -1,11 +1,12 @@
 """This module contains backports to support older Python versions."""
 #
-# (C) Pywikibot team, 2020-2021
+# (C) Pywikibot team, 2014-2021
 #
 # Distributed under the terms of the MIT license.
 #
 from pywikibot.tools import PYTHON_VERSION
 
+
 # functools.cache
 if PYTHON_VERSION >= (3, 9):
     from functools import cache
@@ -14,6 +15,32 @@ else:
     cache = _lru_cache(None)
 
 
+# context
+if PYTHON_VERSION < (3, 7):
+
+    class nullcontext:  # noqa: N801
+
+        """Dummy context manager for Python 3.5/3.6 that does nothing."""
+
+        def __init__(self, result=None):  # noqa: D107
+            self.result = result
+
+        def __enter__(self):
+            return self.result
+
+        def __exit__(self, *args):
+            pass
+else:
+    from contextlib import nullcontext
+
+
+# queue
+if PYTHON_VERSION < (3, 7):
+    from queue import Queue as SimpleQueue
+else:
+    from queue import SimpleQueue
+
+
 # typing
 if PYTHON_VERSION < (3, 5, 2):
     from typing import Dict as DefaultDict
@@ -22,6 +49,15 @@ elif PYTHON_VERSION < (3, 9):
 else:
     from collections import defaultdict as DefaultDict  # noqa: N812
 
+
+if PYTHON_VERSION < (3, 7, 2):
+    from typing import Dict as OrderedDict
+elif PYTHON_VERSION < (3, 9):
+    from typing import OrderedDict
+else:
+    from collections import OrderedDict
+
+
 if PYTHON_VERSION >= (3, 9):
     from collections.abc import Iterable, Sequence
     Dict = dict
@@ -30,7 +66,7 @@ if PYTHON_VERSION >= (3, 9):
     Set = set
     Tuple = tuple
 else:
-    from typing import Dict, FrozenSet, Iterable, List, Set, Sequence, Tuple
+    from typing import Dict, FrozenSet, Iterable, List, Sequence, Set, Tuple
 
 
 # PEP 616 string methods
@@ -39,13 +75,19 @@ if PYTHON_VERSION >= (3, 9):
     removesuffix = str.removesuffix
 else:
     def removeprefix(string: str, prefix: str) -> str:
-        """Remove prefix from a string or return a copy otherwise."""
+        """Remove prefix from a string or return a copy otherwise.
+
+        *New in version 5.4.*
+        """
         if string.startswith(prefix):
             return string[len(prefix):]
         return string[:]
 
     def removesuffix(string: str, suffix: str) -> str:
-        """Remove prefix from a string or return a copy otherwise."""
+        """Remove prefix from a string or return a copy otherwise.
+
+        *New in version 5.4.*
+        """
         if string.endswith(suffix):
             return string[:-len(suffix)]
         return string[:]
