@@ -9,6 +9,17 @@ This module is responsible for
     - Translate site objects with query strings into URLs
     - URL-encoding all data
     - Basic HTTP error handling
+
+This module creates and uses its own ``requests.Session`` object.
+The session is closed if the module terminates.
+If required you can use your own Session object passing it to the
+``http.session`` variable::
+
+    from pywikibot.comms import http
+    session = requests.Session()
+    http.session = session
+
+:py:obj:`flush()` can be called to close the session object.
 """
 #
 # (C) Pywikibot team, 2007-2021
@@ -19,9 +30,8 @@ import atexit
 import codecs
 import re
 import sys
-
 from contextlib import suppress
-from http import cookiejar
+from http import HTTPStatus, cookiejar
 from string import Formatter
 from typing import Optional, Union
 from urllib.parse import quote, urlparse
@@ -30,20 +40,22 @@ from warnings import warn
 import requests
 
 import pywikibot
-
+from pywikibot import config
 from pywikibot.backports import Tuple
-from pywikibot import config2 as config
 from pywikibot.exceptions import (
-    FatalServerError, Server504Error, Server414Error
+    FatalServerError,
+    Server414Error,
+    Server504Error,
 )
 from pywikibot.logging import critical, debug, error, log, warning
 from pywikibot.tools import (
     deprecated,
     deprecated_args,
-    issue_deprecation_warning,
     file_mode_checker,
+    issue_deprecation_warning,
 )
 
+
 try:
     import requests_oauthlib
 except ImportError as e:
@@ -71,7 +83,8 @@ session.cookies = cookie_jar
 
 
 # Prepare flush on quit
-def _flush():
+def flush():
+    """Close the session object. This is called when the module terminates."""
     log('Closing network session.')
     session.close()
 
@@ -81,7 +94,7 @@ def _flush():
     log('Network session closed.')
 
 
-atexit.register(_flush)
+atexit.register(flush)
 
 USER_AGENT_PRODUCTS = {
     'python': 'Python/' + '.'.join(str(i) for i in sys.version_info),
@@ -97,7 +110,7 @@ class _UserAgentFormatter(Formatter):
     def get_value(self, key, args, kwargs):
         """Get field as usual except for version and revision."""
         # This is the Pywikibot version; also map it to {revision} at present.
-        if key == 'version' or key == 'revision':
+        if key in ('version', 'revision'):
             return pywikibot.version.getversiondict()['rev']
         return super().get_value(key, args, kwargs)
 
@@ -136,11 +149,11 @@ def user_agent(site=None, format_string: str = None) -> str:
     """
     Generate the user agent string for a given site and format.
 
-    @param site: The site for which this user agent is intended. May be None.
-    @type site: BaseSite
-    @param format_string: The string to which the values will be added using
+    :param site: The site for which this user agent is intended. May be None.
+    :type site: BaseSite
+    :param format_string: The string to which the values will be added using
         str.format. Is using config.user_agent_format when it is None.
-    @return: The formatted user agent
+    :return: The formatted user agent
     """
     values = USER_AGENT_PRODUCTS.copy()
     values.update(dict.fromkeys(['script', 'script_product'],
@@ -190,7 +203,7 @@ def get_fake_user_agent():
 
     Deprecated, use fake_user_agent() instead.
 
-    @rtype: str
+    :rtype: str
     """
     if isinstance(config.fake_user_agent, str):
         return config.fake_user_agent
@@ -217,26 +230,25 @@ def request(site,
     """
     Request to Site with default error handling and response decoding.
 
-    See L{requests.Session.request} for additional parameters.
+    See :py:obj:`requests.Session.request` for additional parameters.
 
     The optional uri is a relative uri from site base uri including the
     document root '/'.
 
-    @param site: The Site to connect to
-    @type: site: pywikibot.site.BaseSite
-    @param uri: the URI to retrieve
-    @keyword charset: Either a valid charset (usable for str.decode()) or None
+    :param site: The Site to connect to
+    :type site: pywikibot.site.BaseSite
+    :param uri: the URI to retrieve
+    :keyword charset: Either a valid charset (usable for str.decode()) or None
         to automatically chose the charset from the returned header (defaults
         to latin-1)
-    @type charset: CodecInfo, str, None
-    @return: The received data Response
+    :type charset: CodecInfo, str, None
+    :return: The received data Response
     """
     kwargs.setdefault('verify', site.verify_SSL_certificate())
     old_validation = kwargs.pop('disable_ssl_certificate_validation', None)
     if old_validation is not None:
         issue_deprecation_warning('disable_ssl_certificate_validation',
                                   instead='verify',
-                                  warning_class=FutureWarning,
                                   since='20201220')
         kwargs.update(verify=not old_validation)
 
@@ -257,8 +269,8 @@ def get_authentication(uri: str) -> Optional[Tuple[str, str]]:
     """
     Retrieve authentication token.
 
-    @param uri: the URI to access
-    @return: authentication token
+    :param uri: the URI to access
+    :return: authentication token
     """
     parsed_uri = requests.utils.urlparse(uri)
     netloc_parts = parsed_uri.netloc.split('.')
@@ -281,8 +293,8 @@ def error_handling_callback(response):
     """
     Raise exceptions and log alerts.
 
-    @param response: Response returned by Session.request().
-    @type response: L{requests.Response}
+    :param response: Response returned by Session.request().
+    :type response: :py:obj:`requests.Response`
     """
     # TODO: do some error correcting stuff
     if isinstance(response, requests.exceptions.SSLError):
@@ -291,15 +303,15 @@ def error_handling_callback(response):
 
     if isinstance(response, Exception):
         with suppress(Exception):
-            # request.data exception may contain response and request attribute
+            # request exception may contain response and request attribute
             error('An error occurred for uri ' + response.request.url)
         raise response from None
 
-    if response.status_code == 504:
+    if response.status_code == HTTPStatus.GATEWAY_TIMEOUT:
         raise Server504Error('Server {} timed out'
                              .format(urlparse(response.url).netloc))
 
-    if response.status_code == 414:
+    if response.status_code == HTTPStatus.REQUEST_URI_TOO_LONG:
         raise Server414Error('Too long GET request')
 
     # TODO: shall it raise? this might break some code, TBC
@@ -307,36 +319,36 @@ def error_handling_callback(response):
 
     # HTTP status 207 is also a success status for Webdav FINDPROP,
     # used by the version module.
-    if response.status_code not in (200, 207):
+    if response.status_code not in (HTTPStatus.OK, HTTPStatus.MULTI_STATUS):
         warning('Http response status {}'.format(response.status_code))
 
 
-@deprecated_args(callback=True, body='data')
+@deprecated_args(body='data')
 def fetch(uri: str, method: str = 'GET', headers: Optional[dict] = None,
           default_error_handling: bool = True,
           use_fake_user_agent: Union[bool, str] = False, **kwargs):
     """
     HTTP request.
 
-    See L{requests.Session.request} for parameters.
+    See :py:obj:`requests.Session.request` for parameters.
 
-    @param uri: URL to send
-    @param method: HTTP method of the request (default: GET)
-    @param headers: dictionary of headers of the request
-    @param default_error_handling: Use default error handling
-    @param use_fake_user_agent: Set to True to use fake UA, False to use
+    :param uri: URL to send
+    :param method: HTTP method of the request (default: GET)
+    :param headers: dictionary of headers of the request
+    :param default_error_handling: Use default error handling
+    :param use_fake_user_agent: Set to True to use fake UA, False to use
         pywikibot's UA, str to specify own UA. This behaviour might be
         overridden by domain in config.
 
-    @kwarg charset: Either a valid charset (usable for str.decode()) or None
+    :keyword charset: Either a valid charset (usable for str.decode()) or None
         to automatically chose the charset from the returned header (defaults
         to latin-1)
-    @type charset: CodecInfo, str, None
-    @kwarg verify: verify the SSL certificate (default is True)
-    @type verify: bool or path to certificates
-    @kwarg callbacks: Methods to call once data is fetched
-    @type callbacks: list of callable
-    @rtype: L{requests.Response}
+    :type charset: CodecInfo, str, None
+    :keyword verify: verify the SSL certificate (default is True)
+    :type verify: bool or path to certificates
+    :keyword callbacks: Methods to call once data is fetched
+    :type callbacks: list of callable
+    :rtype: :py:obj:`requests.Response`
     """
     # Change user agent depending on fake UA settings.
     # Set header to new UA if needed.
@@ -382,9 +394,9 @@ def fetch(uri: str, method: str = 'GET', headers: Optional[dict] = None,
     auth = get_authentication(uri)
     if auth is not None and len(auth) == 4:
         if isinstance(requests_oauthlib, ImportError):
-            warn('%s' % requests_oauthlib, ImportWarning)
-            error('OAuth authentication not supported: %s'
-                  % requests_oauthlib)
+            warn(str(requests_oauthlib), ImportWarning)
+            error('OAuth authentication not supported: {}'
+                  .format(requests_oauthlib))
             auth = None
         else:
             auth = requests_oauthlib.OAuth1(*auth)
@@ -394,7 +406,6 @@ def fetch(uri: str, method: str = 'GET', headers: Optional[dict] = None,
     if old_validation is not None:
         issue_deprecation_warning('disable_ssl_certificate_validation',
                                   instead='verify',
-                                  warning_class=FutureWarning,
                                   since='20201220')
         kwargs.update(verify=not old_validation)
 
@@ -449,14 +460,18 @@ def _decide_encoding(response, charset) -> Optional[str]:
         """Helper function to try decoding."""
         if encoding is None:
             return None
+
         try:
             content.decode(encoding)
-        except (LookupError, UnicodeDecodeError):
+        except LookupError:
             pywikibot.warning('Unknown or invalid encoding {!r}'
                               .format(encoding))
-            # let chardet do the job
-            return None
-        return encoding
+        except UnicodeDecodeError as e:
+            pywikibot.warning('{} found in {}'.format(e, content))
+        else:
+            return encoding
+
+        return None  # let chardet do the job
 
     header_encoding = _get_encoding_from_response_headers(response)
     if header_encoding is None:
