@@ -4,11 +4,11 @@ This module can do slight modifications to tidy a wiki page's source code.
 
 The changes are not supposed to change the look of the rendered wiki page.
 
-If you wish to run this as an stand-alone script, use:
+If you wish to run this as an stand-alone script, use::
 
     scripts/cosmetic_changes.py
 
-For regular use, it is recommended to put this line into your user-config.py:
+For regular use, it is recommended to put this line into your user-config.py::
 
     cosmetic_changes = True
 
@@ -16,11 +16,11 @@ You may enable cosmetic changes for additional languages by adding the
 dictionary cosmetic_changes_enable to your user-config.py. It should contain
 a tuple of languages for each site where you wish to enable in addition to
 your own langlanguage if cosmetic_changes_mylang_only is True (see below).
-Please set your dictionary by adding such lines to your user-config.py:
+Please set your dictionary by adding such lines to your user-config.py::
 
     cosmetic_changes_enable['wikipedia'] = ('de', 'en', 'fr')
 
-There is another config variable: You can set
+There is another config variable: You can set::
 
     cosmetic_changes_mylang_only = False
 
@@ -33,7 +33,7 @@ a tuple of languages for each site where you wish to disable cosmetic changes.
 You may use it with cosmetic_changes_mylang_only is False, but you can also
 disable your own language. This also overrides the settings in the dictionary
 cosmetic_changes_enable. Please set this dictionary by adding such lines to
-your user-config.py:
+your user-config.py::
 
     cosmetic_changes_disable['wikipedia'] = ('de', 'en', 'fr')
 
@@ -41,11 +41,11 @@ You may disable cosmetic changes for a given script by appending the all
 unwanted scripts to the list cosmetic_changes_deny_script in your
 user-config.py. By default it contains cosmetic_changes.py itself and touch.py.
 This overrides all other enabling settings for cosmetic changes. Please modify
-the given list by adding such lines to your user-config.py:
+the given list by adding such lines to your user-config.py::
 
     cosmetic_changes_deny_script.append('your_script_name_1')
 
-or by adding a list to the given one:
+or by adding a list to the given one::
 
     cosmetic_changes_deny_script += ['your_script_name_1',
                                      'your_script_name_2']
@@ -57,19 +57,27 @@ or by adding a list to the given one:
 #
 import re
 
+from enum import IntEnum
 from typing import Optional
 
 import pywikibot
-
-from pywikibot.page import url2unicode
 from pywikibot import textlib
+from pywikibot.exceptions import InvalidTitleError
 from pywikibot.textlib import (
-    _get_regexes, _MultiTemplateMatchBuilder, FILE_LINK_REGEX
+    FILE_LINK_REGEX,
+    MultiTemplateMatchBuilder,
+    _get_regexes,
 )
 from pywikibot.tools import (
-    deprecated, deprecated_args, first_lower, first_upper,
+    deprecated,
+    deprecated_args,
+    first_lower,
+    first_upper,
     issue_deprecation_warning,
+    ModuleDeprecationWrapper,
 )
+from pywikibot.tools.chars import url2string
+
 
 try:
     import stdnum.isbn as stdnum_isbn
@@ -79,6 +87,7 @@ except ImportError:
 
 # Subpage templates. Must be in lower case,
 # whereas subpage itself must be case sensitive
+# This is also used by interwiki.py
 # TODO: Maybe move it to family file and implement global instances
 moved_links = {
     'ar': (['documentation', 'template documentation', 'شرح', 'توثيق'],
@@ -167,10 +176,21 @@ deprecatedTemplates = {
     }
 }
 
-CANCEL_ALL = False
-CANCEL_PAGE = 1
-CANCEL_METHOD = 2
-CANCEL_MATCH = 3
+
+class CANCEL(IntEnum):
+
+    """Cancel level to ignore exceptions.
+
+    If an error occurred and either skips the page or the method
+    or a single match. ALL raises the exception.
+
+    *New in version 6.3.*
+    """
+
+    ALL = 0
+    PAGE = 1
+    METHOD = 2
+    MATCH = 3
 
 
 def _format_isbn_match(match, strict=True):
@@ -185,7 +205,7 @@ def _format_isbn_match(match, strict=True):
     except stdnum_isbn.ValidationError as e:
         if strict:
             raise
-        pywikibot.log('ISBN "%s" validation error: %s' % (isbn, e))
+        pywikibot.log('ISBN "{}" validation error: {}'.format(isbn, e))
         return isbn
 
     return stdnum_isbn.format(isbn)
@@ -194,7 +214,7 @@ def _format_isbn_match(match, strict=True):
 def _reformat_ISBNs(text, strict=True):
     """Helper function to normalise ISBNs in text.
 
-    @raises Exception: Invalid ISBN encountered when strict enabled
+    :raises Exception: Invalid ISBN encountered when strict enabled
     """
     return textlib.reformat_ISBNs(
         text, lambda match: _format_isbn_match(match, strict=strict))
@@ -204,20 +224,20 @@ class CosmeticChangesToolkit:
 
     """Cosmetic changes toolkit."""
 
-    @deprecated_args(redirect=None, diff='show_diff', site='page')
+    @deprecated_args(redirect=True, diff='show_diff', site='page')
     def __init__(self, page, *,
                  show_diff: bool = False,
                  namespace: Optional[int] = None,
                  pageTitle: Optional[str] = None,
-                 ignore: int = CANCEL_ALL):
+                 ignore: IntEnum = CANCEL.ALL):
         """Initializer.
 
-        @param page: the Page object containing the text to be modified
-        @type page: pywikibot.Page
-        @param show_diff: show difference after replacements (default: False)
-        @param namespace: DEPRECATED namespace parameter
-        @param pageTitle: DEPRECATED page title parameter
-        @param ignore: ignores if an error occurred and either skips the page
+        :param page: the Page object containing the text to be modified
+        :type page: pywikibot.Page
+        :param show_diff: show difference after replacements (default: False)
+        :param namespace: DEPRECATED namespace parameter
+        :param pageTitle: DEPRECATED page title parameter
+        :param ignore: ignores if an error occurred and either skips the page
             or only that method. It can be set one of the CANCEL constants
         """
         if isinstance(page, pywikibot.BaseSite):
@@ -231,7 +251,6 @@ class CosmeticChangesToolkit:
             issue_deprecation_warning(
                 'site parameter of CosmeticChangesToolkit',
                 'a pywikibot.Page object as first parameter',
-                warning_class=FutureWarning,
                 since='20201102')
         else:
             if namespace is not None or pageTitle is not None:
@@ -287,9 +306,9 @@ class CosmeticChangesToolkit:
 
     @classmethod
     @deprecated('CosmeticChangesToolkit with pywikibot.Page object',
-                future_warning=True, since='20200415')
+                since='20200415')
     @deprecated_args(diff='show_diff')
-    def from_page(cls, page, show_diff=False, ignore=CANCEL_ALL):
+    def from_page(cls, page, show_diff=False, ignore=CANCEL.ALL):
         """Create toolkit based on the page."""
         return cls(page, show_diff=show_diff, ignore=ignore)
 
@@ -299,7 +318,7 @@ class CosmeticChangesToolkit:
         try:
             result = method(text)
         except Exception as e:
-            if self.ignore == CANCEL_METHOD:
+            if self.ignore == CANCEL.METHOD:
                 pywikibot.warning('Unable to perform "{}" on "{}"!'
                                   .format(method.__name__, self.title))
                 pywikibot.exception(e)
@@ -318,8 +337,8 @@ class CosmeticChangesToolkit:
         try:
             new_text = self._change(text)
         except Exception as e:
-            if self.ignore == CANCEL_PAGE:
-                pywikibot.warning('Skipped "{0}", because an error occurred.'
+            if self.ignore == CANCEL.PAGE:
+                pywikibot.warning('Skipped "{}", because an error occurred.'
                                   .format(self.title))
                 pywikibot.exception(e)
                 return False
@@ -336,8 +355,8 @@ class CosmeticChangesToolkit:
         Remove their language code prefix.
         """
         if not self.talkpage and pywikibot.calledModuleName() != 'interwiki':
-            interwikiR = re.compile(r'\[\[(?: *:)? *%s *: *([^\[\]\n]*)\]\]'
-                                    % self.site.code)
+            interwikiR = re.compile(r'\[\[(?: *:)? *{} *: *([^\[\]\n]*)\]\]'
+                                    .format(self.site.code))
             text = interwikiR.sub(r'[[\1]]', text)
         return text
 
@@ -439,7 +458,7 @@ class CosmeticChangesToolkit:
             # lowerspaced and underscored namespaces
             for i, item in enumerate(namespaces):
                 item = item.replace(' ', '[ _]')
-                item = '[%s%s]' % (item[0], item[0].lower()) + item[1:]
+                item = '[{}{}]'.format(item[0], item[0].lower()) + item[1:]
                 namespaces[i] = item
             namespaces.append(first_lower(final_ns))
             if final_ns and namespaces:
@@ -457,9 +476,9 @@ class CosmeticChangesToolkit:
                 else:
                     text = textlib.replaceExcept(
                         text,
-                        r'\[\[\s*(%s) *:(?P<nameAndLabel>.*?)\]\]'
-                        % '|'.join(namespaces),
-                        r'[[%s:\g<nameAndLabel>]]' % final_ns,
+                        r'\[\[\s*({}) *:(?P<nameAndLabel>.*?)\]\]'
+                        .format('|'.join(namespaces)),
+                        r'[[{}:\g<nameAndLabel>]]'.format(final_ns),
                         exceptions)
         return text
 
@@ -524,8 +543,8 @@ class CosmeticChangesToolkit:
 
         * Capitalize the article title of the link, if appropriate
 
-        @param text: string to perform the clean-up on
-        @return: text with tidied wikilinks
+        :param text: string to perform the clean-up on
+        :return: text with tidied wikilinks
         """
         # helper function which works on one link and either returns it
         # unmodified, or returns a replacement.
@@ -550,7 +569,7 @@ class CosmeticChangesToolkit:
             page = pywikibot.Page(pywikibot.Link(titleWithSection, self.site))
             try:
                 in_main_namespace = page.namespace() == 0
-            except pywikibot.InvalidTitle:
+            except InvalidTitleError:
                 in_main_namespace = False
             if not in_main_namespace:
                 return match.group()
@@ -576,8 +595,8 @@ class CosmeticChangesToolkit:
                 hadTrailingSpaces = len(titleWithSection) != titleLength
 
             # Convert URL-encoded characters to str
-            titleWithSection = url2unicode(titleWithSection,
-                                           encodings=self.site)
+            titleWithSection = url2string(titleWithSection,
+                                          encodings=self.site.encodings())
 
             if not titleWithSection:
                 # just skip empty links.
@@ -613,13 +632,13 @@ class CosmeticChangesToolkit:
                 firstcase_label = label
 
             if firstcase_label == firstcase_title:
-                newLink = '[[%s]]' % label
+                newLink = '[[{}]]'.format(label)
             # Check if we can create a link with trailing characters
             # instead of a pipelink
             elif (firstcase_label.startswith(firstcase_title)
                   and trailR.sub('', label[len(titleWithSection):]) == ''):
-                newLink = '[[%s]]%s' % (label[:len(titleWithSection)],
-                                        label[len(titleWithSection):])
+                newLink = '[[{}]]{}'.format(label[:len(titleWithSection)],
+                                            label[len(titleWithSection):])
 
             else:
                 # Try to capitalize the first letter of the title.
@@ -629,7 +648,7 @@ class CosmeticChangesToolkit:
                 # uppercase
                 if self.site.sitename == 'wikipedia:de':
                     titleWithSection = first_upper(titleWithSection)
-                newLink = '[[%s|%s]]' % (titleWithSection, label)
+                newLink = '[[{}|{}]]'.format(titleWithSection, label)
             # re-add spaces that were pulled out of the link.
             # Examples:
             #   text[[ title ]]text        -> text [[title]] text
@@ -760,12 +779,19 @@ class CosmeticChangesToolkit:
         """
         Add a space between the equal signs and the section title.
 
-        Example: ==Section title== becomes == Section title ==
+        Example::
 
-        NOTE: This space is recommended in the syntax help on the English and
-        German Wikipedia. It is not wanted on Lojban and English Wiktionary
-        (T168399, T169064) and it might be that it is not wanted on other
-        wikis. If there are any complaints, please file a bug report.
+            ==Section title==
+
+        becomes::
+
+        == Section title ==
+
+        :NOTE: This space is recommended in the syntax help on the
+            English and German Wikipedias. It is not wanted on Lojban and
+            English Wiktionaries (T168399, T169064) and it might be that
+            it is not wanted on other wikis. If there are any complaints,
+            please file a bug report.
         """
         if self.site.sitename in ['wiktionary:jbo', 'wiktionary:en']:
             return text
@@ -779,9 +805,10 @@ class CosmeticChangesToolkit:
         """
         Add a space between the * or # and the text.
 
-        NOTE: This space is recommended in the syntax help on the English,
-        German, and French Wikipedia. It might be that it is not wanted on
-        other wikis. If there are any complaints, please file a bug report.
+        :NOTE: This space is recommended in the syntax help on the
+            English, German and French Wikipedias. It might be that it
+            is not wanted on other wikis. If there are any complaints,
+            please file a bug report.
         """
         if not self.template:
             exceptions = ['comment', 'math', 'nowiki', 'pre',
@@ -798,7 +825,7 @@ class CosmeticChangesToolkit:
     def replaceDeprecatedTemplates(self, text):
         """Replace deprecated templates."""
         exceptions = ['comment', 'math', 'nowiki', 'pre']
-        builder = _MultiTemplateMatchBuilder(self.site)
+        builder = MultiTemplateMatchBuilder(self.site)
 
         if self.site.family.name in deprecatedTemplates \
            and self.site.code in deprecatedTemplates[self.site.family.name]:
@@ -877,7 +904,7 @@ class CosmeticChangesToolkit:
         # dash in external link, where the correct end of the URL can
         # be detected from the file extension. It is very unlikely that
         # this will cause mistakes.
-        extensions = [r'\.{0}'.format(ext)
+        extensions = [r'\.{}'.format(ext)
                       for ext in ['pdf', 'html?', 'php', 'aspx?', 'jsp']]
         text = textlib.replaceExcept(
             text,
@@ -967,7 +994,7 @@ class CosmeticChangesToolkit:
         return text
 
     def fixArabicLetters(self, text):
-        """Fix arabic and persian letters."""
+        """Fix Arabic and Persian letters."""
         if self.site.code not in ['ckb', 'fa']:
             return text
 
@@ -1014,10 +1041,10 @@ class CosmeticChangesToolkit:
 
     def commonsfiledesc(self, text):
         """
-        Clean up file descriptions on the Wikimedia Commons.
+        Clean up file descriptions on Wikimedia Commons.
 
-        It is working according to [1] and works only on pages in the file
-        namespace on the Wikimedia Commons.
+        It works according to [1] and works only on pages in the file
+        namespace on Wikimedia Commons.
 
         [1]:
         https://commons.wikimedia.org/wiki/Commons:Tools/pywiki_file_description_cleanup
@@ -1080,4 +1107,24 @@ class CosmeticChangesToolkit:
 
     def fix_ISBN(self, text):
         """Hyphenate ISBN numbers."""
-        return _reformat_ISBNs(text, strict=self.ignore != CANCEL_MATCH)
+        return _reformat_ISBNs(text, strict=self.ignore != CANCEL.MATCH)
+
+
+_CANCEL_ALL = CANCEL.ALL
+_CANCEL_PAGE = CANCEL.PAGE
+_CANCEL_METHOD = CANCEL.METHOD
+_CANCEL_MATCH = CANCEL.MATCH
+
+wrapper = ModuleDeprecationWrapper(__name__)
+wrapper.add_deprecated_attr('CANCEL_ALL', _CANCEL_ALL,
+                            replacement_name='CANCEL.ALL',
+                            since='20210528')
+wrapper.add_deprecated_attr('CANCEL_PAGE', _CANCEL_PAGE,
+                            replacement_name='CANCEL.PAGE',
+                            since='20210528')
+wrapper.add_deprecated_attr('CANCEL_METHOD', _CANCEL_METHOD,
+                            replacement_name='CANCEL.METHOD',
+                            since='20210528')
+wrapper.add_deprecated_attr('CANCEL_MATCH', _CANCEL_MATCH,
+                            replacement_name='CANCEL.MATCH',
+                            since='20210528')
