@@ -5,13 +5,12 @@
 # Distributed under the terms of the MIT license.
 #
 import json
-
 from typing import Optional
 from urllib.parse import quote
 
 from requests.exceptions import Timeout
 
-from pywikibot import config, warning, Site, sleep
+from pywikibot import Site, config, sleep, warning
 from pywikibot.comms import http
 from pywikibot.exceptions import Error, TimeoutError
 
@@ -35,15 +34,15 @@ class SparqlQuery:
         """
         Create endpoint.
 
-        @param endpoint: SPARQL endpoint URL
-        @param entity_url: URL prefix for any entities returned in a query.
-        @param repo: The Wikibase site which we want to run queries on. If
+        :param endpoint: SPARQL endpoint URL
+        :param entity_url: URL prefix for any entities returned in a query.
+        :param repo: The Wikibase site which we want to run queries on. If
             provided this overrides any value in endpoint and entity_url.
             Defaults to Wikidata.
-        @type repo: pywikibot.site.DataSite
-        @param max_retries: (optional) Maximum number of times to retry after
+        :type repo: pywikibot.site.DataSite
+        :param max_retries: (optional) Maximum number of times to retry after
                errors, defaults to config.max_retries.
-        @param retry_wait: (optional) Minimum time in seconds to wait after an
+        :param retry_wait: (optional) Minimum time in seconds to wait after an
                error, defaults to config.retry_wait seconds (doubles each retry
                until config.retry_max is reached).
         """
@@ -62,7 +61,7 @@ class SparqlQuery:
                     'Please provide the endpoint and entity_url '
                     'parameters instead of a repo.')
             if not self.endpoint:
-                raise Error('The site {0} does not provide a sparql endpoint.'
+                raise Error('The site {} does not provide a sparql endpoint.'
                             .format(repo))
         else:
             if not entity_url:
@@ -86,7 +85,7 @@ class SparqlQuery:
         """
         Return last received response.
 
-        @return: Response object from last request or None
+        :return: Response object from last request or None
         """
         return self.last_response
 
@@ -98,9 +97,9 @@ class SparqlQuery:
         The response is assumed to be in format defined by:
         https://www.w3.org/TR/2013/REC-sparql11-results-json-20130321/
 
-        @param query: Query text
-        @param full_data: Whether return full data objects or only values
-        @return: List of query results or None if query failed
+        :param query: Query text
+        :param full_data: Whether return full data objects or only values
+        :return: List of query results or None if query failed
         """
         data = self.query(query, headers=headers)
         if data and 'results' in data:
@@ -129,9 +128,9 @@ class SparqlQuery:
         """
         Run SPARQL query and return parsed JSON result.
 
-        @param query: Query text
+        :param query: Query text
         """
-        url = '{0}?query={1}'.format(self.endpoint, quote(query))
+        url = '{}?query={}'.format(self.endpoint, quote(query))
         while True:
             try:
                 self.last_response = http.fetch(url, headers=headers)
@@ -150,7 +149,7 @@ class SparqlQuery:
         self.max_retries -= 1
         if self.max_retries < 0:
             raise TimeoutError('Maximum retries attempted without success.')
-        warning('Waiting {0} seconds before retrying.'.format(self.retry_wait))
+        warning('Waiting {} seconds before retrying.'.format(self.retry_wait))
         sleep(self.retry_wait)
         # double the next wait, but do not exceed config.retry_max seconds
         self.retry_wait = min(config.retry_max, self.retry_wait * 2)
@@ -159,7 +158,7 @@ class SparqlQuery:
         """
         Run SPARQL ASK query and return boolean result.
 
-        @param query: Query text
+        :param query: Query text
         """
         data = self.query(query, headers=headers)
         return data['boolean']
@@ -170,14 +169,14 @@ class SparqlQuery:
 
         Items are returned as Wikibase IDs.
 
-        @param query: Query string. Must contain ?{item_name} as one of the
+        :param query: Query string. Must contain ?{item_name} as one of the
             projected values.
-        @param item_name: Name of the value to extract
-        @param result_type: type of the iterable in which
+        :param item_name: Name of the value to extract
+        :param result_type: type of the iterable in which
               SPARQL results are stored (default set)
-        @type result_type: iterable
-        @return: item ids, e.g. Q1234
-        @rtype: same as result_type
+        :type result_type: iterable
+        :return: item ids, e.g. Q1234
+        :rtype: same as result_type
         """
         res = self.select(query, full_data=True)
         if res:
@@ -208,7 +207,7 @@ class URI(SparqlNode):
         """
         Get ID of Wikibase object identified by the URI.
 
-        @return: ID of Wikibase object, e.g. Q1234
+        :return: ID of Wikibase object, e.g. Q1234
         """
         urllen = len(self.entity_url)
         if self.value.startswith(self.entity_url):
