@@ -6,7 +6,6 @@
 #
 import difflib
 import math
-
 from collections.abc import Sequence
 from difflib import _format_range_unified as format_range_unified
 from itertools import zip_longest
@@ -32,9 +31,9 @@ class Hunk:
         """
         Initializer.
 
-        @param a: sequence of lines
-        @param b: sequence of lines
-        @param grouped_opcode: list of 5-tuples describing how to turn a into
+        :param a: sequence of lines
+        :param b: sequence of lines
+        :param grouped_opcode: list of 5-tuples describing how to turn a into
             b. It has the same format as returned by difflib.get_opcodes().
         """
         self.a = a
@@ -59,8 +58,9 @@ class Hunk:
         self.b_rng = (first[3], last[4])
 
         self.header = self.get_header()
-        self.diff_plain_text = '%s\n%s' % (self.header, self.diff_plain_text)
-        self.diff_text = '%s' % self.diff_text
+        self.diff_plain_text = '{hunk.header}\n{hunk.diff_plain_text}' \
+                               .format(hunk=self)
+        self.diff_text = str(self.diff_text)
 
         self.reviewed = self.PENDING
 
@@ -78,7 +78,7 @@ class Hunk:
     def create_diff(self):
         """Generator of diff text for this hunk, without formatting."""
         # make sure each line ends with '\n' to prevent
-        # behaviour like http://bugs.python.org/issue2142
+        # behaviour like https://bugs.python.org/issue2142
         def check_line(line):
             return line if line.endswith('\n') else line + '\n'
 
@@ -197,8 +197,7 @@ class Hunk:
     def __repr__(self):
         """Return a reconstructable representation."""
         # TODO
-        return '%s(a, b, %s)' \
-               % (self.__class__.__name__, self.group)
+        return '{}(a, b, {})'.format(self.__class__.__name__, self.group)
 
 
 class _SuperHunk(Sequence):
@@ -243,16 +242,16 @@ class PatchManager:
                  replace_invisible=False) -> None:
         """Initializer.
 
-        @param text_a: base text
-        @param text_b: target text
-        @param context: number of lines which are context
-        @type context: int
-        @param by_letter: if text_a and text_b are single lines, comparison can
+        :param text_a: base text
+        :param text_b: target text
+        :param context: number of lines which are context
+        :type context: int
+        :param by_letter: if text_a and text_b are single lines, comparison can
             be done letter by letter.
-        @type by_letter: bool
-        @param replace_invisible: Replace invisible characters like U+200e with
+        :type by_letter: bool
+        :param replace_invisible: Replace invisible characters like U+200e with
             the charnumber in brackets (e.g. <200e>).
-        @type replace_invisible: bool
+        :type replace_invisible: bool
         """
         self.a = text_a.splitlines(True)
         self.b = text_b.splitlines(True)
@@ -359,7 +358,7 @@ class PatchManager:
         """Generate a diff text for the given hunks."""
         def extend_context(start, end):
             """Add context lines."""
-            return ''.join('  {0}\n'.format(line.rstrip())
+            return ''.join('  {}\n'.format(line.rstrip())
                            for line in self.a[start:end])
 
         context_range = self._get_context_range(hunks)
@@ -431,7 +430,7 @@ class PatchManager:
             answers += ['?']
 
             pywikibot.output(self._generate_diff(super_hunk))
-            choice = pywikibot.input('Accept this hunk [{0}]?'.format(
+            choice = pywikibot.input('Accept this hunk [{}]?'.format(
                 ','.join(answers)))
             if choice not in answers:
                 choice = '?'
@@ -499,7 +498,7 @@ class PatchManager:
                     position = next_hunk_position
                 elif next_hunk:  # nothing entered is silently ignored
                     pywikibot.error(
-                        'Invalid hunk number "{0}"'.format(next_hunk))
+                        'Invalid hunk number "{}"'.format(next_hunk))
             elif choice == 'j':
                 position = next_pending
             elif choice == 'J':
@@ -513,7 +512,7 @@ class PatchManager:
                                + super_hunks[position].split()
                                + super_hunks[position + 1:])
                 pywikibot.output(
-                    'Split into {0} hunks'.format(len(super_hunk._hunks)))
+                    'Split into {} hunks'.format(len(super_hunk._hunks)))
             else:  # choice == '?':
                 pywikibot.output(color_format(
                     '{purple}{0}{default}', '\n'.join(
@@ -585,8 +584,8 @@ def html_comparator(compare_string: str) -> dict:
     Site.compare() returns HTML that is useful for displaying on a page.
     Here we use BeautifulSoup to get the un-HTML-ify the context of changes.
     Finally we present the added and deleted contexts.
-    @param compare_string: HTML string from mediawiki API
-    @return: deleted and added list of contexts
+    :param compare_string: HTML string from MediaWiki API
+    :return: deleted and added list of contexts
     """
     from bs4 import BeautifulSoup
 
