@@ -4,8 +4,7 @@
 #
 # Distributed under the terms of the MIT license.
 #
-from pywikibot import config
-from pywikibot import family
+from pywikibot import config, family
 
 
 # The Wikidata family
@@ -21,6 +20,9 @@ class Family(family.WikimediaFamily):
         'beta': 'wikidata.beta.wmflabs.org',
     }
 
+    # Sites we want to edit but not count as real languages
+    test_codes = ['test', 'beta']
+
     interwiki_forward = 'wikipedia'
 
     category_redirect_templates = {
