@@ -26,12 +26,12 @@ class Family(family.SubdomainFamily, family.WikimediaFamily):
 
     languages_by_size = [
         'pl', 'en', 'ru', 'de', 'fr', 'zh', 'he', 'it', 'es', 'ar', 'uk', 'cs',
-        'gu', 'mul', 'pt', 'sr', 'fa', 'hu', 'sv', 'ml', 'ko', 'bn', 'sa',
-        'te', 'sl', 'ta', 'hy', 'el', 'ro', 'fi', 'ja', 'th', 'tr', 'nap',
-        'vi', 'az', 'ca', 'la', 'br', 'nl', 'kn', 'hr', 'no', 'eo', 'is',
-        'vec', 'pms', 'id', 'hi', 'be', 'et', 'lij', 'da', 'mk', 'yi', 'mr',
-        'as', 'bg', 'li', 'lt', 'eu', 'wa', 'or', 'pa', 'cy', 'gl', 'bs',
-        'sah', 'sk', 'zh-min-nan', 'fo',
+        'gu', 'mul', 'pt', 'sr', 'fa', 'hu', 'sv', 'ko', 'ml', 'sa', 'bn',
+        'te', 'ta', 'sl', 'hy', 'el', 'tr', 'ro', 'fi', 'ja', 'vi', 'nap',
+        'az', 'la', 'ca', 'br', 'nl', 'kn', 'hr', 'th', 'no', 'eo', 'is',
+        'vec', 'pms', 'id', 'hi', 'be', 'et', 'lij', 'da', 'mk', 'yi', 'as',
+        'mr', 'bg', 'li', 'lt', 'wa', 'eu', 'or', 'pa', 'cy', 'gl', 'bs',
+        'sah', 'sk', 'zh-min-nan', 'fo', 'ban',
     ]
 
     # Sites we want to edit but not count as real languages
