@@ -16,8 +16,8 @@ class Family(family.SubdomainFamily, family.WikimediaFamily):
     name = 'wikiversity'
 
     languages_by_size = [
-        'de', 'en', 'fr', 'zh', 'it', 'ru', 'cs', 'pt', 'es', 'sl', 'ar', 'sv',
-        'fi', 'el', 'hi', 'ko', 'ja',
+        'de', 'en', 'fr', 'zh', 'it', 'ru', 'cs', 'pt', 'es', 'ar', 'sl', 'sv',
+        'fi', 'el', 'ko', 'hi', 'ja',
     ]
 
     test_codes = ['beta']
