@@ -27,21 +27,21 @@ class Family(family.SubdomainFamily, family.WikimediaFamily):
     ]
 
     languages_by_size = [
-        'en', 'fr', 'mg', 'ru', 'de', 'zh', 'sh', 'es', 'el', 'sv', 'nl', 'pl',
-        'ku', 'lt', 'it', 'ca', 'fi', 'ta', 'hu', 'tr', 'io', 'hy', 'ko', 'ja',
-        'pt', 'kn', 'vi', 'sr', 'th', 'chr', 'hi', 'ro', 'no', 'id', 'et',
-        'ml', 'cs', 'my', 'uz', 'li', 'or', 'te', 'eo', 'fa', 'ar', 'gl', 'jv',
-        'oc', 'az', 'eu', 'uk', 'br', 'da', 'lo', 'ast', 'simple', 'is', 'hr',
-        'la', 'fj', 'tg', 'ky', 'sk', 'bg', 'wa', 'ur', 'ps', 'cy', 'skr',
-        'vo', 'he', 'af', 'zh-min-nan', 'shn', 'scn', 'sl', 'tl', 'pa', 'sw',
-        'fy', 'bn', 'nn', 'lv', 'ka', 'sq', 'co', 'mn', 'pnb', 'min', 'lb',
-        'nds', 'bs', 'nah', 'ms', 'yue', 'sa', 'kk', 'km', 'om', 'diq', 'vec',
-        'tk', 'mk', 'be', 'sm', 'hsb', 'shy', 'gd', 'ga', 'an', 'wo', 'mni',
-        'gom', 'mr', 'ang', 'ia', 'tt', 'fo', 'mt', 'sd', 'nia', 'gn', 'ie',
-        'so', 'csb', 'ug', 'bcl', 'st', 'roa-rup', 'si', 'hif', 'zu', 'kl',
-        'mi', 'su', 'ay', 'jbo', 'ln', 'yi', 'gu', 'na', 'gv', 'kw', 'tpi',
-        'ne', 'rw', 'ts', 'qu', 'ha', 'ss', 'iu', 'am', 'dv', 'sg', 'ti', 'tn',
-        'ks', 'mnw',
+        'en', 'fr', 'mg', 'ru', 'zh', 'de', 'sh', 'es', 'sv', 'el', 'nl', 'pl',
+        'ku', 'lt', 'it', 'ca', 'fi', 'hu', 'ta', 'tr', 'io', 'hy', 'ko', 'ja',
+        'pt', 'kn', 'vi', 'sr', 'th', 'hi', 'ro', 'no', 'et', 'id', 'cs', 'ml',
+        'my', 'uz', 'li', 'or', 'te', 'eo', 'fa', 'ar', 'gl', 'jv', 'oc', 'az',
+        'eu', 'uk', 'br', 'ast', 'da', 'lo', 'simple', 'is', 'hr', 'bn', 'la',
+        'fj', 'tg', 'ky', 'skr', 'bg', 'sk', 'wa', 'ur', 'ps', 'cy', 'vo',
+        'he', 'shn', 'af', 'zh-min-nan', 'sl', 'scn', 'tl', 'pa', 'om', 'sw',
+        'fy', 'nn', 'ka', 'lv', 'sq', 'nds', 'min', 'co', 'mn', 'pnb', 'lb',
+        'ms', 'bs', 'nah', 'yue', 'sa', 'kk', 'km', 'diq', 'vec', 'tk', 'be',
+        'mk', 'sm', 'hsb', 'shy', 'gd', 'ga', 'nia', 'an', 'wo', 'mni', 'gom',
+        'mr', 'mnw', 'ang', 'ia', 'fo', 'tt', 'mt', 'sd', 'gn', 'ie', 'so',
+        'ks', 'csb', 'ug', 'su', 'bcl', 'st', 'roa-rup', 'si', 'hif', 'zu',
+        'kl', 'mi', 'ay', 'jbo', 'ln', 'yi', 'gu', 'na', 'gv', 'kw', 'tpi',
+        'ne', 'rw', 'ts', 'ha', 'qu', 'ss', 'chr', 'iu', 'am', 'dv', 'sg',
+        'ti', 'tn',
     ]
 
     category_redirect_templates = {
