@@ -9,25 +9,23 @@ import logging
 import re
 import string
 import sys
+import types
 import urllib.parse as urlparse
 import warnings
-
 from importlib import import_module
 from itertools import chain
 from os.path import basename, dirname, splitext
 from typing import Optional
 
 import pywikibot
-
-from pywikibot.backports import Dict, List, Tuple
 from pywikibot import config
-from pywikibot.exceptions import UnknownFamily, FamilyMaintenanceWarning
+from pywikibot.backports import Dict, List, Tuple
+from pywikibot.exceptions import FamilyMaintenanceWarning, UnknownFamilyError
 from pywikibot.tools import (
+    ModuleDeprecationWrapper,
     classproperty,
     deprecated,
     deprecated_args,
-    frozenmap,
-    ModuleDeprecationWrapper,
 )
 
 
@@ -111,13 +109,14 @@ class Family:
         'ps', 'jam', 'koi', 'km', 'pcd', 'pms', 'tpi', 'nds', 'pl', 'pnt',
         'pt', 'aa', 'kaa', 'crh', 'ty', 'ksh', 'ro', 'rmy', 'rm', 'qu', 'rue',
         'ru', 'sah', 'szy', 'se', 'sm', 'sa', 'sg', 'sat', 'skr', 'sc', 'sco',
-        'stq', 'st', 'nso', 'tn', 'sq', 'scn', 'si', 'simple', 'sd', 'ss',
-        'sk', 'sl', 'cu', 'szl', 'so', 'ckb', 'srn', 'sr', 'sh', 'su', 'fi',
-        'sv', 'tl', 'shn', 'ta', 'kab', 'roa-tara', 'tt', 'te', 'tet', 'th',
-        'ti', 'tg', 'to', 'chr', 'chy', 've', 'tcy', 'tr', 'azb', 'tk', 'tw',
-        'tyv', 'din', 'udm', 'bug', 'uk', 'ur', 'ug', 'za', 'vec', 'vep', 'vi',
-        'vo', 'fiu-vro', 'wa', 'zh-classical', 'vls', 'war', 'wo', 'wuu', 'ts',
-        'yi', 'yo', 'zh-yue', 'diq', 'zea', 'bat-smg', 'zh', 'zh-tw', 'zh-cn',
+        'trv', 'stq', 'st', 'nso', 'tn', 'sq', 'scn', 'si', 'simple', 'sd',
+        'ss', 'sk', 'sl', 'cu', 'szl', 'so', 'ckb', 'srn', 'sr', 'sh', 'su',
+        'fi', 'sv', 'tl', 'shn', 'ta', 'kab', 'roa-tara', 'tt', 'tay', 'te',
+        'tet', 'th', 'ti', 'tg', 'to', 'chr', 'chy', 've', 'tcy', 'tr', 'azb',
+        'tk', 'tw', 'tyv', 'din', 'udm', 'bug', 'uk', 'ur', 'ug', 'za', 'vec',
+        'vep', 'vi', 'vo', 'fiu-vro', 'wa', 'zh-classical', 'vls', 'war', 'wo',
+        'wuu', 'ts', 'yi', 'yo', 'zh-yue', 'diq', 'zea', 'bat-smg', 'zh',
+        'zh-tw', 'zh-cn',
     ]
 
     # The revised sorting order by first word from meta
@@ -147,14 +146,14 @@ class Family:
         'hz', 'uz', 'pa', 'pi', 'pfl', 'pag', 'pnb', 'pap', 'ps', 'jam', 'km',
         'pcd', 'pms', 'nds', 'pl', 'pnt', 'pt', 'aa', 'kaa', 'crh', 'ty',
         'ksh', 'ro', 'rmy', 'rm', 'qu', 'ru', 'rue', 'sah', 'szy', 'se', 'sa',
-        'sg', 'sat', 'skr', 'sc', 'sco', 'stq', 'st', 'nso', 'tn', 'sq', 'scn',
-        'si', 'simple', 'sd', 'ss', 'sk', 'sl', 'cu', 'szl', 'so', 'ckb',
-        'srn', 'sr', 'sh', 'fi', 'sv', 'tl', 'ta', 'kab', 'kbp', 'roa-tara',
-        'tt', 'te', 'tet', 'th', 'vi', 'ti', 'tg', 'tpi', 'chr', 'chy', 've',
-        'tcy', 'tr', 'azb', 'tk', 'tw', 'tyv', 'din', 'udm', 'uk', 'ur', 'ug',
-        'za', 'vec', 'vep', 'vo', 'fiu-vro', 'wa', 'zh-classical', 'vls',
-        'war', 'wo', 'wuu', 'ts', 'yi', 'yo', 'zh-yue', 'diq', 'zea',
-        'bat-smg', 'zh', 'zh-tw', 'zh-cn',
+        'sg', 'sat', 'skr', 'sc', 'sco', 'trv', 'stq', 'st', 'nso', 'tn', 'sq',
+        'scn', 'si', 'simple', 'sd', 'ss', 'sk', 'sl', 'cu', 'szl', 'so',
+        'ckb', 'srn', 'sr', 'sh', 'fi', 'sv', 'tl', 'ta', 'kab', 'kbp',
+        'roa-tara', 'tt', 'tay', 'te', 'tet', 'th', 'vi', 'ti', 'tg', 'tpi',
+        'chr', 'chy', 've', 'tcy', 'tr', 'azb', 'tk', 'tw', 'tyv', 'din',
+        'udm', 'uk', 'ur', 'ug', 'za', 'vec', 'vep', 'vo', 'fiu-vro', 'wa',
+        'zh-classical', 'vls', 'war', 'wo', 'wuu', 'ts', 'yi', 'yo', 'zh-yue',
+        'diq', 'zea', 'bat-smg', 'zh', 'zh-tw', 'zh-cn',
     ]
 
     # Order for fy: alphabetical by code, but y counts as i
@@ -209,6 +208,7 @@ class Family:
         'cv': '[a-zа-яĕçăӳ"»]*',
         'cy': '[àáâèéêìíîïòóôûŵŷa-z]*',
         'da': '[a-zæøå]*',
+        'dag': '[ɛɣŋɔʒƐƔŊƆƷa-z]*',
         'de': '[äöüßa-z]*',
         'din': '[äëɛɛ̈éɣïŋöɔɔ̈óa-z]*',
         'dsb': '[äöüßa-z]*',
@@ -318,6 +318,7 @@ class Family:
         'se': '[a-zàáâçčʒǯđðéèêëǧǥȟíìîïıǩŋñóòôõßšŧúùûýÿüžþæøåäö]*',
         'sg': '[a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]*',
         'sh': '[a-zčćđžš]*',
+        'shi': '[ⴰ-ⵯa-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙḍḥɛṛɣṣṭẓḌḤƐṚƔṢṬẒʷ]*',
         'sk': '[a-záäčďéíľĺňóôŕšťúýž]*',
         'skr': '[ابپتٹثجچحخدڈذرڑزژسشصضطظعغفقکگلمنںوؤہھیئےآأءۃٻڄݙڋڰڳݨ]*',
         'sl': '[a-zčćđžš]*',
@@ -545,13 +546,13 @@ class Family:
     _families = {}
 
     @staticmethod
-    @deprecated_args(fatal=None)
+    @deprecated_args(fatal=True)
     def load(fam: Optional[str] = None):
         """Import the named family.
 
-        @param fam: family name (if omitted, uses the configured default)
-        @return: a Family instance configured for the named family.
-        @raises pywikibot.exceptions.UnknownFamily: family not known
+        :param fam: family name (if omitted, uses the configured default)
+        :return: a Family instance configured for the named family.
+        :raises pywikibot.exceptions.UnknownFamilyError: family not known
         """
         if fam is None:
             fam = config.family
@@ -571,7 +572,7 @@ class Family:
                 Family._families[fam] = myfamily
                 return Family._families[fam]
         else:
-            raise UnknownFamily('Family %s does not exist' % fam)
+            raise UnknownFamilyError('Family {} does not exist'.format(fam))
 
         try:
             # Ignore warnings due to dots in family names.
@@ -582,7 +583,7 @@ class Family:
                 sys.path.append(dirname(family_file))
                 mod = import_module(splitext(basename(family_file))[0])
         except ImportError:
-            raise UnknownFamily('Family %s does not exist' % fam)
+            raise UnknownFamilyError('Family {} does not exist'.format(fam))
         cls = mod.Family.instance
         if cls.name != fam:
             warnings.warn('Family name {} does not match family module name {}'
@@ -657,11 +658,17 @@ class Family:
         self._get_cr_templates(code, fallback)
 
     def get_edit_restricted_templates(self, code):
-        """Return tuple of edit restricted templates."""
+        """Return tuple of edit restricted templates.
+
+        *New in version 3.0.*
+        """
         return self.edit_restricted_templates.get(code, ())
 
     def get_archived_page_templates(self, code):
-        """Return tuple of archived page templates."""
+        """Return tuple of archived page templates.
+
+        *New in version 3.0.*
+        """
         return self.archived_page_templates.get(code, ())
 
     def disambig(self, code, fallback='_default'):
@@ -683,8 +690,8 @@ class Family:
 
         May be overridden to return 'https'. Other protocols are not supported.
 
-        @param code: language code
-        @return: protocol that this family uses
+        :param code: language code
+        :return: protocol that this family uses
         """
         return 'http'
 
@@ -692,23 +699,14 @@ class Family:
         """
         Return whether a HTTPS certificate should be verified.
 
-        @param code: language code
-        @return: flag to verify the SSL certificate;
+        *Renamed in version 5.3.*
+
+        :param code: language code
+        :return: flag to verify the SSL certificate;
                  set it to False to allow access if certificate has an error.
         """
         return True
 
-    @deprecated('verify_SSL_certificate', since='20201013',
-                future_warning=True)
-    def ignore_certificate_error(self, code: str) -> bool:
-        """
-        Return whether a HTTPS certificate error should be ignored.
-
-        @param code: language code
-        @return: flag to allow access if certificate has an error.
-        """
-        return not self.verify_SSL_certificate
-
     def hostname(self, code):
         """The hostname to use for standard http connections."""
         return self.langs[code]
@@ -728,9 +726,9 @@ class Family:
         but needs to be overridden in the family file for any wiki that
         uses a different value.
 
-        @param code: Site code
-        @raises KeyError: code is not recognised
-        @return: URL path without ending '/'
+        :param code: Site code
+        :raises KeyError: code is not recognised
+        :return: URL path without ending '/'
         """
         return '/w'
 
@@ -753,52 +751,58 @@ class Family:
         """
         Prefix uri with port and hostname.
 
-        @param code: The site code
-        @param uri: The absolute path after the hostname
-        @param protocol: The protocol which is used. If None it'll determine
+        :param code: The site code
+        :param uri: The absolute path after the hostname
+        :param protocol: The protocol which is used. If None it'll determine
             the protocol from the code.
-        @return: The full URL ending with uri
+        :return: The full URL ending with uri
         """
         protocol, host = self._hostname(code, protocol)
         if protocol == 'https':
             uri = self.ssl_pathprefix(code) + uri
-        return urlparse.urljoin('{0}://{1}'.format(protocol, host), uri)
+        return urlparse.urljoin('{}://{}'.format(protocol, host), uri)
 
     def path(self, code):
         """Return path to index.php."""
-        return '%s/index.php' % self.scriptpath(code)
+        return '{}/index.php'.format(self.scriptpath(code))
 
     def querypath(self, code):
         """Return path to query.php."""
-        return '%s/query.php' % self.scriptpath(code)
+        return '{}/query.php'.format(self.scriptpath(code))
 
     def apipath(self, code):
         """Return path to api.php."""
-        return '%s/api.php' % self.scriptpath(code)
+        return '{}/api.php'.format(self.scriptpath(code))
 
     def eventstreams_host(self, code):
-        """Hostname for EventStreams."""
+        """Hostname for EventStreams.
+
+        *New in version 3.0.*
+        """
         raise NotImplementedError('This family does not support EventStreams')
 
     def eventstreams_path(self, code):
-        """Return path for EventStreams."""
+        """Return path for EventStreams.
+
+        *New in version 3.0.*
+        """
         raise NotImplementedError('This family does not support EventStreams')
 
     @deprecated_args(name='title')
     def get_address(self, code, title):
         """Return the path to title using index.php with redirects disabled."""
-        return '%s?title=%s&redirect=no' % (self.path(code), title)
+        return '{}?title={}&redirect=no'.format(self.path(code), title)
 
     def interface(self, code):
         """
         Return interface to use for code.
 
-        @rtype: str or subclass of BaseSite
+        :rtype: str or subclass of BaseSite
         """
         if code in self.interwiki_removals:
             if code in self.codes:
-                pywikibot.warn('Interwiki removal %s is in %s codes'
-                               % (code, self))
+                pywikibot.warn('Interwiki removal {} is in {} codes'
+                               .format(code, self))
             if code in self.closed_wikis:
                 return 'ClosedSite'
             if code in self.removed_wikis:
@@ -812,21 +816,22 @@ class Family:
 
         It is first checking if a domain of this family is in the the domain of
         the URL. If that is the case it's checking all codes and verifies that
-        a path generated via L{APISite.article_path} and L{Family.path} matches
-        the path of the URL together with the hostname for that code.
+        a path generated via :py:obj:`APISite.article_path` and
+        :py:obj:`Family.path` matches the path of the URL together with
+        the hostname for that code.
 
-        It is using L{Family.domains} to first check if a domain applies and
-        then iterates over L{Family.codes} to actually determine which code
-        applies.
+        It is using :py:obj:`Family.domains` to first check if a domain
+        applies and then iterates over :py:obj:`Family.codes` to actually
+        determine which code applies.
 
-        @param url: the URL which may contain a C{$1}. If it's missing it is
+        :param url: the URL which may contain a ``$1``. If it's missing it is
             assumed to be at the end and if it's present nothing is allowed
             after it.
-        @return: The language code of the url. None if that url is not from
+        :return: The language code of the url. None if that url is not from
             this family.
-        @raises RuntimeError: When there are multiple languages in this family
+        :raises RuntimeError: When there are multiple languages in this family
             which would work with the given URL.
-        @raises ValueError: When text is present after $1.
+        :raises ValueError: When text is present after $1.
         """
         parsed = urlparse.urlparse(url)
         if not re.match('(https?)?$', parsed.scheme):
@@ -839,8 +844,8 @@ class Family:
         # Discard $1 and everything after it
         path, _, suffix = path.partition('$1')
         if suffix:
-            raise ValueError('Text after the $1 placeholder is not supported '
-                             '(T111513).')
+            raise ValueError('Url: {}\nText {} after the $1 placeholder is '
+                             'not supported (T111513).'.format(url, suffix))
 
         for domain in self.domains:
             if domain in parsed.netloc:
@@ -848,7 +853,7 @@ class Family:
         else:
             return None
 
-        matched_sites = []
+        matched_sites = set()
         for code in chain(self.codes,
                           getattr(self, 'test_codes', ()),
                           getattr(self, 'closed_wikis', ()),
@@ -857,21 +862,21 @@ class Family:
                 # Use the code and family instead of the url
                 # This is only creating a Site instance if domain matches
                 site = pywikibot.Site(code, self.name)
-                pywikibot.log('Found candidate {0}'.format(site))
+                pywikibot.log('Found candidate {}'.format(site))
 
                 for iw_url in site._interwiki_urls():
                     if path.startswith(iw_url):
-                        matched_sites += [site]
+                        matched_sites.add(site)
                         break
 
         if len(matched_sites) == 1:
-            return matched_sites[0].code
+            return matched_sites.pop().code
 
         if not matched_sites:
             return None
 
         raise RuntimeError(
-            'Found multiple matches for URL "{0}": {1}'
+            'Found multiple matches for URL "{}": {}'
             .format(url, ', '.join(str(s) for s in matched_sites)))
 
     def maximum_GET_length(self, code):
@@ -880,7 +885,7 @@ class Family:
 
     def dbName(self, code):
         """Return the name of the MySQL database."""
-        return '%s%s' % (code, self.name)
+        return '{}{}'.format(code, self.name)
 
     def encoding(self, code):
         """Return the encoding for a specific language wiki."""
@@ -903,7 +908,7 @@ class Family:
     def __ne__(self, other):
         try:
             return not self.__eq__(other)
-        except UnknownFamily:
+        except UnknownFamilyError:
             return False
 
     def __hash__(self):
@@ -913,7 +918,7 @@ class Family:
         return self.name
 
     def __repr__(self):
-        return 'Family("%s")' % self.name
+        return 'Family("{}")'.format(self.name)
 
     def shared_image_repository(self, code):
         """Return the shared image repository, if any."""
@@ -928,7 +933,7 @@ class Family:
         Do a conversion on the retrieved text from the Wiki.
 
         For example a X-conversion in Esperanto
-        U{https://en.wikipedia.org/wiki/Esperanto_orthography#X-system}.
+        https://en.wikipedia.org/wiki/Esperanto_orthography#X-system.
         """
         return getText
 
@@ -937,7 +942,7 @@ class Family:
         Do a conversion on the text to insert on the Wiki.
 
         For example a X-conversion in Esperanto
-        U{https://en.wikipedia.org/wiki/Esperanto_orthography#X-system}.
+        https://en.wikipedia.org/wiki/Esperanto_orthography#X-system.
         """
         return putText
 
@@ -948,12 +953,12 @@ class Family:
 
         Interwiki replacements override removals for the same code.
 
-        @return: mapping of old codes to new codes (or None)
-        @rtype: dict
+        :return: mapping of old codes to new codes (or None)
+        :rtype: dict
         """
         data = {code: None for code in self.interwiki_removals}
         data.update(self.interwiki_replacements)
-        return frozenmap(data)
+        return types.MappingProxyType(data)
 
     @obsolete.setter
     def obsolete(self, data):
@@ -972,7 +977,7 @@ class Family:
 
         These domains may also exist in another family.
 
-        @rtype: set of str
+        :rtype: set of str
         """
         return set(cls.langs.values())
 
@@ -981,7 +986,7 @@ class Family:
         """
         Get list of codes used by this family.
 
-        @rtype: set of str
+        :rtype: set of str
         """
         return set(cls.langs.keys())
 
@@ -1031,11 +1036,11 @@ class SubdomainFamily(Family):
             codes += cls.closed_wikis
 
         # shortcut this classproperty
-        cls.langs = {code: '{0}.{1}'.format(code, cls.domain)
+        cls.langs = {code: '{}.{}'.format(code, cls.domain)
                      for code in codes}
 
         if hasattr(cls, 'code_aliases'):
-            cls.langs.update({alias: '{0}.{1}'.format(code, cls.domain)
+            cls.langs.update({alias: '{}.{}'.format(code, cls.domain)
                               for alias, code in cls.code_aliases.items()})
 
         return cls.langs
@@ -1046,8 +1051,8 @@ class SubdomainFamily(Family):
         if cls.languages_by_size:
             return cls.languages_by_size
         raise NotImplementedError(
-            'Family %s needs property "languages_by_size" or "codes"'
-            % cls.name)
+            'Family {} needs property "languages_by_size" or "codes"'
+            .format(cls.name))
 
     @classproperty
     def domains(cls):
@@ -1057,7 +1062,10 @@ class SubdomainFamily(Family):
 
 class FandomFamily(Family):
 
-    """Common features of Fandom families."""
+    """Common features of Fandom families.
+
+    *Renamed in version 3.0.*
+    """
 
     @classproperty
     def langs(cls):
@@ -1160,9 +1168,9 @@ class WikimediaFamily(Family):
     # Completely removed
     removed_wikis = []  # type: List[str]
 
-    # WikimediaFamily uses wikibase for the category name containing
+    # WikimediaFamily uses Wikibase for the category name containing
     # disambiguation pages for the various languages. We need the
-    # wikibase code and item number:
+    # Wikibase code and item number:
     disambcatname = {'wikidata': 'Q1982926'}
 
     # UrlShortener extension is only usable on metawiki, and this wiki can
@@ -1179,7 +1187,7 @@ class WikimediaFamily(Family):
             return 'wikimedia.org'
 
         raise NotImplementedError(
-            "Family %s needs to define property 'domain'" % cls.name)
+            "Family {} needs to define property 'domain'".format(cls.name))
 
     @classproperty
     def interwiki_removals(cls):
@@ -1189,7 +1197,7 @@ class WikimediaFamily(Family):
     @classproperty
     def interwiki_replacements(cls):
         """Return an interwiki code replacement mapping."""
-        return frozenmap(cls.code_aliases)
+        return types.MappingProxyType(cls.code_aliases)
 
     def shared_image_repository(self, code):
         """Return Wikimedia Commons as the shared image repository."""
@@ -1210,23 +1218,23 @@ class WikimediaFamily(Family):
 
 class WikimediaOrgFamily(SingleSiteFamily, WikimediaFamily):
 
-    """Single site family for sites hosted at C{*.wikimedia.org}."""
+    """Single site family for sites hosted at ``*.wikimedia.org``."""
 
     @classproperty
     def domain(cls):
         """Return the parents domain with a subdomain prefix."""
-        return '{0}.wikimedia.org'.format(cls.name)
+        return '{}.wikimedia.org'.format(cls.name)
 
 
-@deprecated_args(site=None)
+@deprecated_args(site=True)
 def AutoFamily(name: str, url: str):
     """
     Family that automatically loads the site configuration.
 
-    @param name: Name for the family
-    @param url: API endpoint URL of the wiki
-    @return: Generated family class
-    @rtype: SingleSiteFamily
+    :param name: Name for the family
+    :param url: API endpoint URL of the wiki
+    :return: Generated family class
+    :rtype: SingleSiteFamily
     """
     url = urlparse.urlparse(url)
     domain = url.netloc
@@ -1249,5 +1257,5 @@ def AutoFamily(name: str, url: str):
 
 
 wrapper = ModuleDeprecationWrapper(__name__)
-wrapper._add_deprecated_attr('WikiaFamily', replacement=FandomFamily,
-                             since='20190420')
+wrapper.add_deprecated_attr('WikiaFamily', replacement=FandomFamily,
+                            since='20190420')
