@@ -9,10 +9,8 @@ from contextlib import suppress
 from typing import Optional
 
 import pywikibot
-
 from pywikibot.backports import List
 from pywikibot.exceptions import Error, HiddenKeyError
-from pywikibot.tools import deprecated
 
 
 _logger = 'wiki'
@@ -41,8 +39,8 @@ class LogEntry(UserDict):
         self.site = site
         expected_type = self._expected_type
         if expected_type is not None and expected_type != self.type():
-            raise Error('Wrong log type! Expecting %s, received %s instead.'
-                        % (expected_type, self.type()))
+            raise Error('Wrong log type! Expecting {}, received {} instead.'
+                        .format(expected_type, self.type()))
 
     def __missing__(self, key: str):
         """Debug when the key is missing.
@@ -52,7 +50,7 @@ class LogEntry(UserDict):
 
         It also logs debugging information when a key is missing.
         """
-        pywikibot.debug('API log entry received:\n' + repr(self),
+        pywikibot.debug('API log entry received:\n{!r}'.format(self),
                         _logger)
         hidden = {'action', 'logpage', 'ns', 'pageid', 'params', 'title'}
         if ((key in hidden and 'actionhidden' in self)
@@ -67,8 +65,8 @@ class LogEntry(UserDict):
 
     def __repr__(self) -> str:
         """Return a string representation of LogEntry object."""
-        return '<{0}({1}, logid={2})>'.format(type(self).__name__,
-                                              self.site.sitename, self.logid())
+        return '<{}({}, logid={})>'.format(type(self).__name__,
+                                           self.site.sitename, self.logid())
 
     def __hash__(self):
         """Combine site and logid as the hash."""
@@ -77,7 +75,7 @@ class LogEntry(UserDict):
     def __eq__(self, other) -> bool:
         """Compare if self is equal to other."""
         if not isinstance(other, LogEntry):
-            pywikibot.debug("'{0}' cannot be compared with '{1}'"
+            pywikibot.debug("'{}' cannot be compared with '{}'"
                             .format(type(self).__name__, type(other).__name__),
                             _logger)
             return False
@@ -96,29 +94,19 @@ class LogEntry(UserDict):
         """
         Additional data for some log entry types.
 
-        @rtype: dict or None
+        :rtype: dict or None
         """
         with suppress(KeyError):
             return self['params']
 
         return self[self._expected_type]
 
-    @deprecated('page()', since='20150617', future_warning=True)
-    def title(self):
-        """
-        DEPRECATED: Alias for page().
-
-        This is going to be replaced by just returning the title as a string
-        instead of a Page instance.
-        """
-        return self.page()
-
     def page(self):
         """
         Page on which action was performed.
 
-        @return: page on action was performed
-        @rtype: pywikibot.Page
+        :return: page on action was performed
+        :rtype: pywikibot.Page
         """
         if not hasattr(self, '_page'):
             self._page = pywikibot.Page(self.site, self['title'])
@@ -136,8 +124,6 @@ class OtherLogEntry(LogEntry):
 
     """A log entry class for unspecified log events."""
 
-    pass
-
 
 class UserTargetLogEntry(LogEntry):
 
@@ -149,8 +135,8 @@ class UserTargetLogEntry(LogEntry):
         This returns a User object instead of the Page object returned by the
         superclass method.
 
-        @return: target user
-        @rtype: pywikibot.User
+        :return: target user
+        :rtype: pywikibot.User
         """
         if not hasattr(self, '_page'):
             self._page = pywikibot.User(self.site, self['title'])
@@ -182,10 +168,10 @@ class BlockEntry(LogEntry):
         """
         Return the blocked account or IP.
 
-        @return: the Page object of username or IP if this block action
+        :return: the Page object of username or IP if this block action
             targets a username or IP, or the blockid if this log reflects
             the removal of an autoblock
-        @rtype: pywikibot.Page or int
+        :rtype: pywikibot.Page or int
         """
         # TODO what for IP ranges ?
         if self.isAutoblockRemoval:
@@ -199,7 +185,7 @@ class BlockEntry(LogEntry):
 
         It raises an Error if the entry is an unblocking log entry.
 
-        @return: list of flags strings
+        :return: list of flags strings
         """
         if self.action() == 'unblock':
             return []
@@ -217,7 +203,7 @@ class BlockEntry(LogEntry):
         """
         Return a datetime.timedelta representing the block duration.
 
-        @return: datetime.timedelta, or None if block is indefinite.
+        :return: datetime.timedelta, or None if block is indefinite.
         """
         if not hasattr(self, '_duration'):
             if self.expiry() is None:
@@ -231,7 +217,7 @@ class BlockEntry(LogEntry):
         """
         Return a Timestamp representing the block expiry date.
 
-        @rtype: pywikibot.Timestamp or None
+        :rtype: pywikibot.Timestamp or None
         """
         if not hasattr(self, '_expiry'):
             details = self._params.get('expiry')
@@ -277,7 +263,7 @@ class UploadEntry(LogEntry):
         """
         Return FilePage on which action was performed.
 
-        @rtype: pywikibot.FilePage
+        :rtype: pywikibot.FilePage
         """
         if not hasattr(self, '_page'):
             self._page = pywikibot.FilePage(self.site, self['title'])
@@ -290,11 +276,6 @@ class MoveEntry(LogEntry):
 
     _expected_type = 'move'
 
-    @deprecated('target_ns.id', since='20150518', future_warning=True)
-    def new_ns(self):
-        """Return namespace id of target page."""
-        return self.target_ns.id
-
     @property
     def target_ns(self):
         """Return namespace object of target page."""
@@ -303,11 +284,6 @@ class MoveEntry(LogEntry):
                                     if 'target_ns' in self._params
                                     else self._params['new_ns']]
 
-    @deprecated('target_page', since='20150518', future_warning=True)
-    def new_title(self):
-        """Return page object of the new title."""
-        return self.target_page
-
     @property
     def target_title(self):
         """Return the target title."""
@@ -321,7 +297,7 @@ class MoveEntry(LogEntry):
         """
         Return target page object.
 
-        @rtype: pywikibot.Page
+        :rtype: pywikibot.Page
         """
         if not hasattr(self, '_target_page'):
             self._target_page = pywikibot.Page(self.site, self.target_title)
@@ -381,12 +357,12 @@ class LogEntryFactory:
         """
         Initializer.
 
-        @param site: The site on which the log entries are created.
-        @type site: BaseSite
-        @param logtype: The log type of the log entries, if known in advance.
+        :param site: The site on which the log entries are created.
+        :type site: BaseSite
+        :param logtype: The log type of the log entries, if known in advance.
                         If None, the Factory will fetch the log entry from
                         the data to create each object.
-        @type logtype: (letype) str : move/block/patrol/etc...
+        :type logtype: (letype) str : move/block/patrol/etc...
         """
         self._site = site
         if logtype is None:
@@ -401,10 +377,10 @@ class LogEntryFactory:
         """
         Instantiate the LogEntry object representing logdata.
 
-        @param logdata: <item> returned by the api
-        @type logdata: dict
+        :param logdata: <item> returned by the api
+        :type logdata: dict
 
-        @return: LogEntry object representing logdata
+        :return: LogEntry object representing logdata
         """
         return self._creator(logdata)
 
@@ -412,9 +388,9 @@ class LogEntryFactory:
         """
         Return the class corresponding to the @logtype string parameter.
 
-        @return: specified subclass of LogEntry
-        @rtype: LogEntry
-        @raise KeyError: logtype is not valid
+        :return: specified subclass of LogEntry
+        :rtype: LogEntry
+        :raise KeyError: logtype is not valid
         """
         if logtype not in self._site.logtypes:
             raise KeyError('{} is not a valid logtype'.format(logtype))
@@ -426,9 +402,9 @@ class LogEntryFactory:
         """
         Return the class corresponding to the @logtype string parameter.
 
-        @return: specified subclass of LogEntry
-        @rtype: LogEntry
-        @note: this class method cannot verify whether the given logtype
+        :return: specified subclass of LogEntry
+        :rtype: LogEntry
+        :note: this class method cannot verify whether the given logtype
             already exits for a given site; to verify use Site.logtypes
             or use the get_valid_entry_class instance method instead.
         """
@@ -448,13 +424,13 @@ class LogEntryFactory:
         """
         Check for logtype from data, and creates the correct LogEntry.
 
-        @param logdata: log entry data
-        @rtype: LogEntry
+        :param logdata: log entry data
+        :rtype: LogEntry
         """
         try:
             logtype = logdata['type']
         except KeyError:
-            pywikibot.debug('API log entry received:\n{0}'.format(logdata),
+            pywikibot.debug('API log entry received:\n{}'.format(logdata),
                             _logger)
             raise Error("Log entry has no 'type' key")
 
