@@ -9,9 +9,10 @@ import os
 import sys
 
 # logging levels
-from logging import DEBUG, INFO, WARNING, ERROR, CRITICAL
+from logging import CRITICAL, DEBUG, ERROR, INFO, WARNING
 from typing import Optional
 
+
 STDOUT = 16
 VERBOSE = 18
 INPUT = 25
@@ -132,12 +133,12 @@ def stdout(text, decoder=None, newline=True, **kwargs):
     another process. All other text will be sent to stderr.
     See: https://en.wikipedia.org/wiki/Pipeline_%28Unix%29
 
-    @param text: the message printed via stdout logger to the user.
-    @param decoder: If None, text should be a unicode string else it should
+    :param text: the message printed via stdout logger to the user.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
     """
     logoutput(text, decoder, newline, STDOUT, **kwargs)
 
@@ -146,12 +147,12 @@ def warning(text: str, decoder: Optional[str] = None,
             newline: bool = True, **kwargs):
     """Output a warning message to the user via the userinterface.
 
-    @param text: the message the user wants to display.
-    @param decoder: If None, text should be a unicode string else it
+    :param text: the message the user wants to display.
+    :param decoder: If None, text should be a unicode string else it
         should be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
     """
     logoutput(text, decoder, newline, WARNING, **kwargs)
 
@@ -159,12 +160,12 @@ def warning(text: str, decoder: Optional[str] = None,
 def error(text, decoder=None, newline=True, **kwargs):
     """Output an error message to the user via the userinterface.
 
-    @param text: the message containing the error which occurred.
-    @param decoder: If None, text should be a unicode string else it should
+    :param text: the message containing the error which occurred.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
     """
     logoutput(text, decoder, newline, ERROR, **kwargs)
 
@@ -172,12 +173,12 @@ def error(text, decoder=None, newline=True, **kwargs):
 def log(text, decoder=None, newline=True, **kwargs):
     """Output a record to the log file.
 
-    @param text: the message which is to be logged to the log file.
-    @param decoder: If None, text should be a unicode string else it should
+    :param text: the message which is to be logged to the log file.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
     """
     logoutput(text, decoder, newline, VERBOSE, **kwargs)
 
@@ -185,12 +186,12 @@ def log(text, decoder=None, newline=True, **kwargs):
 def critical(text, decoder=None, newline=True, **kwargs):
     """Output a critical record to the user via the userinterface.
 
-    @param text: the critical message which is to be displayed to the user.
-    @param decoder: If None, text should be a unicode string else it should
+    :param text: the critical message which is to be displayed to the user.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
     """
     logoutput(text, decoder, newline, CRITICAL, **kwargs)
 
@@ -198,13 +199,13 @@ def critical(text, decoder=None, newline=True, **kwargs):
 def debug(text, layer, decoder=None, newline=True, **kwargs):
     """Output a debug record to the log file.
 
-    @param text: the message of the debug record to be logged to the log file.
-    @param decoder: If None, text should be a unicode string else it should
+    :param text: the message of the debug record to be logged to the log file.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
-    @param layer: The name of the logger that text will be sent to.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
+    :param layer: The name of the logger that text will be sent to.
     """
     logoutput(text, decoder, newline, DEBUG, layer, **kwargs)
 
@@ -228,13 +229,13 @@ def exception(msg=None, decoder=None, newline=True, tb=False, **kwargs):
 
     This function should only be called from an Exception handler.
 
-    @param msg: If not None,contains the description of the exception occurred.
-    @param decoder: If None, text should be a unicode string else it should
+    :param msg: If not None,contains the description of the exception occurred.
+    :param decoder: If None, text should be a unicode string else it should
         be encoded in the given encoding.
-    @param newline: If True, a line feed will be added after printing the text.
-    @param kwargs: The keyword arguments can be found in the python doc:
-        https://docs.python.org/3/howto/logging-cookbook.html.
-    @param tb: Set to True in order to output traceback also.
+    :param newline: If True, a line feed will be added after printing the text.
+    :param kwargs: The keyword arguments can be found in the python doc:
+        https://docs.python.org/3/howto/logging-cookbook.html
+    :param tb: Set to True in order to output traceback also.
     """
     if isinstance(msg, BaseException):
         exc_info = 1
