@@ -8,39 +8,34 @@
 import codecs
 import os
 import webbrowser
-
 from enum import IntEnum
 from typing import Optional
 from warnings import warn
 
 import pywikibot
-
-from pywikibot import config, __url__
+import pywikibot.data.api
+from pywikibot import __url__, config
 from pywikibot.comms import http
-from pywikibot.exceptions import NoUsername
+from pywikibot.exceptions import APIError, NoUsernameError
 from pywikibot.tools import (
-    deprecated_args, file_mode_checker, normalize_username, remove_last_args,
+    ModuleDeprecationWrapper,
+    deprecated_args,
+    file_mode_checker,
+    normalize_username,
+    remove_last_args,
 )
 
+
 try:
     import mwoauth
 except ImportError as e:
     mwoauth = e
 
 
-class OAuthImpossible(ImportError):
-
-    """OAuth authentication is not possible on your system."""
-
-    pass
-
-
 class _PasswordFileWarning(UserWarning):
 
     """The format of password file is incorrect."""
 
-    pass
-
 
 _logger = 'wiki.login'
 
@@ -89,7 +84,7 @@ class LoginManager:
 
     """Site login manager."""
 
-    @deprecated_args(username='user', verbose=None, sysop=None)
+    @deprecated_args(username='user', verbose=True, sysop=True)
     def __init__(self, password: Optional[str] = None,
                  site=None, user: Optional[str] = None):
         """
@@ -97,13 +92,13 @@ class LoginManager:
 
         All parameters default to defaults in user-config.
 
-        @param site: Site object to log into
-        @type site: BaseSite
-        @param user: username to use.
+        :param site: Site object to log into
+        :type site: BaseSite
+        :param user: username to use.
             If user is None, the username is loaded from config.usernames.
-        @param password: password to use
+        :param password: password to use
 
-        @raises pywikibot.exceptions.NoUsername: No username is configured
+        :raises pywikibot.exceptions.NoUsernameError: No username is configured
             for the requested site.
         """
         site = self.site = site or pywikibot.Site()
@@ -114,7 +109,7 @@ class LoginManager:
             try:
                 user = code_to_usr.get(site.code) or code_to_usr['*']
             except KeyError:
-                raise NoUsername(
+                raise NoUsernameError(
                     'ERROR: '
                     'username for {site.family.name}:{site.code} is undefined.'
                     '\nIf you have a username for that site, '
@@ -131,9 +126,9 @@ class LoginManager:
         """
         Check that the username exists on the site.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Users}
+        :see: https://www.mediawiki.org/wiki/API:Users
 
-        @raises pywikibot.exceptions.NoUsername: Username doesn't exist in
+        :raises pywikibot.exceptions.NoUsernameError: Username doesn't exist in
             user list.
         """
         # convert any Special:BotPassword usernames to main account equivalent
@@ -149,7 +144,7 @@ class LoginManager:
         try:
             data = self.site.allusers(start=main_username, total=1)
             user = next(iter(data))
-        except pywikibot.data.api.APIError as e:
+        except APIError as e:
             if e.code == 'readapidenied':
                 pywikibot.warning("Could not check user '{}' exists on {}"
                                   .format(main_username, self.site))
@@ -158,8 +153,8 @@ class LoginManager:
 
         if user['name'] != main_username:
             # Report the same error as server error code NotExists
-            raise NoUsername("Username '{}' does not exist on {}"
-                             .format(main_username, self.site))
+            raise NoUsernameError("Username '{}' does not exist on {}"
+                                  .format(main_username, self.site))
 
     def botAllowed(self):
         """
@@ -244,12 +239,12 @@ class LoginManager:
                 entry = None
 
             if not isinstance(entry, tuple):
-                warn('Invalid tuple in line {0}'.format(line_nr),
+                warn('Invalid tuple in line {}'.format(line_nr),
                      _PasswordFileWarning)
                 continue
 
             if not 2 <= len(entry) <= 4:
-                warn('The length of tuple in line {0} should be 2 to 4 ({1} '
+                warn('The length of tuple in line {} should be 2 to 4 ({} '
                      'given)'.format(line_nr, entry), _PasswordFileWarning)
                 continue
 
@@ -281,17 +276,17 @@ class LoginManager:
         """
         Attempt to log into the server.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Login}
+        :see: https://www.mediawiki.org/wiki/API:Login
 
-        @param retry: infinitely retry if the API returns an unknown error
-        @type retry: bool
+        :param retry: infinitely retry if the API returns an unknown error
+        :type retry: bool
 
-        @param autocreate: if true, allow auto-creation of the account
+        :param autocreate: if true, allow auto-creation of the account
                            using unified login
-        @type autocreate: bool
+        :type autocreate: bool
 
-        @raises pywikibot.exceptions.NoUsername: Username is not recognised by
-            the site.
+        :raises pywikibot.exceptions.NoUsernameError: Username is not
+            recognised by the site.
         """
         if not self.password:
             # First check that the username exists,
@@ -310,7 +305,7 @@ class LoginManager:
                          .format(name=self.login_name, site=self.site))
         try:
             self.login_to_site()
-        except pywikibot.data.api.APIError as e:
+        except APIError as e:
             error_code = e.code
             pywikibot.error('Login failed ({}).'.format(error_code))
             if error_code in self._api_error:
@@ -318,7 +313,7 @@ class LoginManager:
                     self.login_name, self._api_error[error_code], self.site)
                 if error_code in ('Failed', 'FAIL'):
                     error_msg += '\n.{}'.format(e.info)
-                raise NoUsername(error_msg)
+                raise NoUsernameError(error_msg)
 
             # TODO: investigate other unhandled API codes (bug T75539)
             if retry:
@@ -344,10 +339,10 @@ class BotPassword:
         BotPassword function by using a separate password paired with a
         suffixed username of the form <username>@<suffix>.
 
-        @param suffix: Suffix of the login name
-        @param password: bot password
+        :param suffix: Suffix of the login name
+        :param password: bot password
 
-        @raises _PasswordFileWarning: suffix improperly specified
+        :raises _PasswordFileWarning: suffix improperly specified
         """
         if '@' in suffix:
             warn('The BotPassword entry should only include the suffix',
@@ -359,9 +354,9 @@ class BotPassword:
         """
         Construct the login name from the username and suffix.
 
-        @param user: username (without suffix)
+        :param user: username (without suffix)
         """
-        return '{0}@{1}'.format(username, self.suffix)
+        return '{}@{}'.format(username, self.suffix)
 
 
 class OauthLoginManager(LoginManager):
@@ -371,7 +366,7 @@ class OauthLoginManager(LoginManager):
     # NOTE: Currently OauthLoginManager use mwoauth directly to complete OAuth
     # authentication process
 
-    @deprecated_args(sysop=None)
+    @deprecated_args(sysop=True)
     def __init__(self, password: Optional[str] = None, site=None,
                  user: Optional[str] = None):
         """
@@ -379,17 +374,17 @@ class OauthLoginManager(LoginManager):
 
         All parameters default to defaults in user-config.
 
-        @param site: Site object to log into
-        @type site: BaseSite
-        @param user: consumer key
-        @param password: consumer secret
+        :param site: Site object to log into
+        :type site: BaseSite
+        :param user: consumer key
+        :param password: consumer secret
 
-        @raises pywikibot.exceptions.NoUsername: No username is configured
+        :raises pywikibot.exceptions.NoUsernameError: No username is configured
             for the requested site.
-        @raises OAuthImpossible: mwoauth isn't installed
+        :raises ImportError: mwoauth isn't installed
         """
         if isinstance(mwoauth, ImportError):
-            raise OAuthImpossible('mwoauth is not installed: %s.' % mwoauth)
+            raise ImportError('mwoauth is not installed: {}.'.format(mwoauth))
         assert password is not None and user is not None
         super().__init__(password=None, site=site, user=None)
         if self.password:
@@ -404,13 +399,13 @@ class OauthLoginManager(LoginManager):
         """
         Attempt to log into the server.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Login}
+        :see: https://www.mediawiki.org/wiki/API:Login
 
-        @param retry: infinitely retry if exception occurs during
+        :param retry: infinitely retry if exception occurs during
             authentication.
-        @type retry: bool
-        @param force: force to re-authenticate
-        @type force: bool
+        :type retry: bool
+        :param force: force to re-authenticate
+        :type force: bool
         """
         if self.access_token is None or force:
             pywikibot.output(
@@ -443,9 +438,9 @@ class OauthLoginManager(LoginManager):
         """
         Return OAuth consumer key token and secret token.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Tokens}
+        :see: https://www.mediawiki.org/wiki/API:Tokens
 
-        @rtype: tuple of two str
+        :rtype: tuple of two str
         """
         return self._consumer_token
 
@@ -454,9 +449,9 @@ class OauthLoginManager(LoginManager):
         """
         Return OAuth access key token and secret token.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Tokens}
+        :see: https://www.mediawiki.org/wiki/API:Tokens
 
-        @rtype: tuple of two str
+        :rtype: tuple of two str
         """
         return self._access_token
 
@@ -476,3 +471,12 @@ class OauthLoginManager(LoginManager):
         except Exception as e:
             pywikibot.error(e)
             return None
+
+
+OAuthImpossible = ImportError
+
+wrapper = ModuleDeprecationWrapper(__name__)
+wrapper.add_deprecated_attr(
+    'OAuthImpossible',
+    replacement_name='ImportError',
+    since='20210423')
