@@ -26,11 +26,19 @@ OCR support of page scans via:
 import json
 import re
 import time
-
 from functools import partial
-from requests.exceptions import ReadTimeout
+from http import HTTPStatus
 from typing import Optional
 
+from requests.exceptions import ReadTimeout
+
+import pywikibot
+from pywikibot import textlib
+from pywikibot.comms import http
+from pywikibot.data.api import Request
+from pywikibot.exceptions import Error, OtherPageSaveError
+
+
 try:
     from bs4 import BeautifulSoup
 except ImportError as e:
@@ -48,13 +56,6 @@ else:
     else:
         _bs4_soup = partial(BeautifulSoup, features='lxml')
 
-import pywikibot
-
-from pywikibot.comms import http
-from pywikibot.data.api import Request
-from pywikibot.exceptions import OtherPageSaveError
-from pywikibot import textlib
-from pywikibot.tools import ModuleDeprecationWrapper
 
 _logger = 'proofreadpage'
 
@@ -172,7 +173,8 @@ class ProofreadPage(pywikibot.Page):
     def __init__(self, source, title=''):
         """Instantiate a ProofreadPage object.
 
-        @raise UnknownExtension: source Site has no ProofreadPage Extension.
+        :raise UnknownExtensionError: source Site has no ProofreadPage
+            Extension.
         """
         if not isinstance(source, pywikibot.site.BaseSite):
             site = source.site
@@ -216,7 +218,7 @@ class ProofreadPage(pywikibot.Page):
         - extension = 'jpg'
         - number = None
 
-        @return: (base, ext, num).
+        :return: (base, ext, num).
         """
         left, sep, right = self.title(with_ns=False).rpartition('/')
         if sep:
@@ -242,8 +244,8 @@ class ProofreadPage(pywikibot.Page):
 
         To force reload, delete index and call it again.
 
-        @return: the Index page for this ProofreadPage
-        @rtype: IndexPage or None
+        :return: the Index page for this ProofreadPage
+        :rtype: IndexPage or None
         """
         if not hasattr(self, '_index'):
             index_ns = self.site.proofread_index_ns
@@ -267,12 +269,12 @@ class ProofreadPage(pywikibot.Page):
         page, others = self._index
         if others:
             pywikibot.warning('{} linked to several Index pages.'.format(self))
-            pywikibot.output('{0}{1!s}'.format(' ' * 9, [page] + others))
+            pywikibot.output('{}{!s}'.format(' ' * 9, [page] + others))
 
             if page:
                 pywikibot.output(
-                    '{0}Selected Index: {1}'.format(' ' * 9, page))
-                pywikibot.output('{0}remaining: {1!s}'.format(' ' * 9, others))
+                    '{}Selected Index: {}'.format(' ' * 9, page))
+                pywikibot.output('{}remaining: {!s}'.format(' ' * 9, others))
 
         if not page:
             pywikibot.warning('Page {} is not linked to any Index page.'
@@ -323,8 +325,8 @@ class ProofreadPage(pywikibot.Page):
     @decompose
     def ql(self, value):
         if value not in self.site.proofread_levels:
-            raise ValueError('Not valid QL value: %s (legal values: %s)'
-                             % (value, self.site.proofread_levels))
+            raise ValueError('Not valid QL value: {} (legal values: {})'
+                             .format(value, self.site.proofread_levels))
         # TODO: add logic to validate ql value change, considering
         # site.proofread_levels.
         self._full_header.ql = value
@@ -347,8 +349,8 @@ class ProofreadPage(pywikibot.Page):
         try:
             return self.site.proofread_levels[self.ql]
         except KeyError:
-            pywikibot.warning('Not valid status set for %s: quality level = %s'
-                              % (self.title(as_link=True), self.ql))
+            pywikibot.warning('Not valid status set for {}: quality level = {}'
+                              .format(self.title(as_link=True), self.ql))
             return None
 
     def without_text(self):
@@ -441,9 +443,9 @@ class ProofreadPage(pywikibot.Page):
         Mainly for use within the class, called by other methods.
         Use self.header, self.body and self.footer to set page content,
 
-        @param value: New value or None
+        :param value: New value or None
 
-        @raise Error: the page is not formatted according to ProofreadPage
+        :raise Error: the page is not formatted according to ProofreadPage
             extension.
         """
         self._text = value
@@ -460,13 +462,12 @@ class ProofreadPage(pywikibot.Page):
     def _decompose_page(self):
         """Split Proofread Page text in header, body and footer.
 
-        @raise Error: the page is not formatted according to ProofreadPage
+        :raise Error: the page is not formatted according to ProofreadPage
             extension.
         """
         def _assert_len(len_oq, len_cq, title):
             if (len_oq != len_cq) or (len_oq < 2 or len_cq < 2):
-                raise pywikibot.Error('ProofreadPage {}: invalid format'
-                                      .format(title))
+                raise Error('ProofreadPage {}: invalid format'.format(title))
 
         # Property force page text loading.
         text = self.text
@@ -539,11 +540,11 @@ class ProofreadPage(pywikibot.Page):
     def url_image(self) -> str:
         """Get the file url of the scan of ProofreadPage.
 
-        @return: file url of the scan ProofreadPage or None.
+        :return: file url of the scan ProofreadPage or None.
 
-        @raises Exception: in case of http errors
-        @raise ImportError: if bs4 is not installed, _bs4_soup() will raise
-        @raises ValueError: in case of no prp_page_image src found for scan
+        :raises Exception: in case of http errors
+        :raise ImportError: if bs4 is not installed, _bs4_soup() will raise
+        :raises ValueError: in case of no prp_page_image src found for scan
         """
         # wrong link fails with various possible Exceptions.
         if not hasattr(self, '_url_image'):
@@ -551,7 +552,7 @@ class ProofreadPage(pywikibot.Page):
             if self.exists():
                 url = self.full_url()
             else:
-                path = 'w/index.php?title={0}&action=edit&redlink=1'
+                path = 'w/index.php?title={}&action=edit&redlink=1'
                 url = self.site.base_url(path.format(self.title(as_url=True)))
 
             try:
@@ -569,7 +570,8 @@ class ProofreadPage(pywikibot.Page):
                 # if None raises TypeError.
                 self._url_image = self._url_image['src']
             except (TypeError, AttributeError):
-                raise ValueError('No prp-page-image src found for %s.' % self)
+                raise ValueError('No prp-page-image src found for {}.'
+                                 .format(self))
             else:
                 self._url_image = 'https:' + self._url_image
 
@@ -578,7 +580,7 @@ class ProofreadPage(pywikibot.Page):
     def _ocr_callback(self, cmd_uri, parser_func=None, ocr_tool=None):
         """OCR callback function.
 
-        @return: tuple (error, text [error description in case of error]).
+        :return: tuple (error, text [error description in case of error]).
         """
         def identity(x):
             return x
@@ -604,7 +606,7 @@ class ProofreadPage(pywikibot.Page):
             try:
                 response = http.fetch(cmd_uri)
             except ReadTimeout as e:
-                pywikibot.warning('ReadTimeout %s: %s' % (cmd_uri, e))
+                pywikibot.warning('ReadTimeout {}: {}'.format(cmd_uri, e))
             except Exception as e:
                 pywikibot.error('"{}": {}'.format(cmd_uri, e))
                 return True, e
@@ -618,13 +620,13 @@ class ProofreadPage(pywikibot.Page):
         else:
             return True, ReadTimeout
 
-        if 400 <= response.status_code < 600:
+        if HTTPStatus.BAD_REQUEST <= response.status_code < 600:
             return True, 'Http response status {}'.format(response.status_code)
 
         data = json.loads(response.text)
 
         if ocr_tool == self._PHETOOLS:  # phetools
-            assert 'error' in data, 'Error from phetools: %s' % data
+            assert 'error' in data, 'Error from phetools: {}'.format(data)
             assert data['error'] in [0, 1, 2, 3], \
                 'Error from phetools: {}'.format(data)
             error, _text = bool(data['error']), data['text']
@@ -635,7 +637,7 @@ class ProofreadPage(pywikibot.Page):
                 error, _text = False, data['text']
 
         if error:
-            pywikibot.error('OCR query %s: %s' % (cmd_uri, _text))
+            pywikibot.error('OCR query {}: {}'.format(cmd_uri, _text))
             return error, _text
         return error, parser_func(_text)
 
@@ -645,7 +647,7 @@ class ProofreadPage(pywikibot.Page):
         This is the main method for 'phetools'.
         Fallback method is ocr.
 
-        @raise ImportError: if bs4 is not installed, _bs4_soup() will raise
+        :raise ImportError: if bs4 is not installed, _bs4_soup() will raise
         """
         def parse_hocr_text(txt):
             """Parse hocr text."""
@@ -676,7 +678,7 @@ class ProofreadPage(pywikibot.Page):
         try:
             url_image = self.url_image
         except ValueError:
-            error_text = 'No prp-page-image src found for %s.' % self
+            error_text = 'No prp-page-image src found for {}.'.format(self)
             pywikibot.error(error_text)
             return True, error_text
 
@@ -704,12 +706,12 @@ class ProofreadPage(pywikibot.Page):
 
         It is the user's responsibility to reset quality level accordingly.
 
-        @param ocr_tool: 'phetools' or 'googleOCR', default is 'phetools'
+        :param ocr_tool: 'phetools' or 'googleOCR', default is 'phetools'
 
-        @return: OCR text for the page.
+        :return: OCR text for the page.
 
-        @raise TypeError: wrong ocr_tool keyword arg.
-        @raise ValueError: something went wrong with OCR process.
+        :raise TypeError: wrong ocr_tool keyword arg.
+        :raise ValueError: something went wrong with OCR process.
         """
         if ocr_tool is None:  # default value
             ocr_tool = self._PHETOOLS
@@ -733,7 +735,7 @@ class ProofreadPage(pywikibot.Page):
         if not error:
             return text
         raise ValueError(
-            '{0}: not possible to perform OCR. {1}'.format(self, text))
+            '{}: not possible to perform OCR. {}'.format(self, text))
 
 
 class PurgeRequest(Request):
@@ -779,8 +781,9 @@ class IndexPage(pywikibot.Page):
         possibility to define range, filter by quality levels and page
         existence.
 
-        @raise UnknownExtension: source Site has no ProofreadPage Extension.
-        @raise ImportError: bs4 is not installed.
+        :raise UnknownExtensionError: source Site has no ProofreadPage
+            Extension.
+        :raise ImportError: bs4 is not installed.
         """
         # Check if BeautifulSoup is imported.
         if isinstance(BeautifulSoup, ImportError):
@@ -887,7 +890,9 @@ class IndexPage(pywikibot.Page):
         # </a>
 
         # Try to purge or raise ValueError.
-        if not self._soup.find_all('a', attrs=attrs):
+        found = self._soup.find_all('a', attrs=attrs)
+        attrs = {'class': re.compile('prp-pagequality|new')}
+        if not found:
             self.purge()
             del self._parsed_text
             self._parsed_text = self._get_parsed_page()
@@ -898,7 +903,6 @@ class IndexPage(pywikibot.Page):
                     'class="new" in: {}.'.format(self))
 
         # Search for attribute "prp-pagequality" or "new" in tags:
-        attrs = {'class': re.compile('prp-pagequality|new')}
         page_cnt = 0
         for a_tag in self._soup.find_all('a', attrs=attrs):
             label = a_tag.text.lstrip('0')  # Label is not converted to int.
@@ -920,7 +924,7 @@ class IndexPage(pywikibot.Page):
                 continue
 
             if page not in self._all_page_links:
-                raise pywikibot.Error('Page {} not recognised.'.format(page))
+                raise Error('Page {} not recognised.'.format(page))
 
             # In order to avoid to fetch other Page:title links outside
             # the Pages section of the Index page; these should hopefully be
@@ -931,8 +935,8 @@ class IndexPage(pywikibot.Page):
             # Sanity check if WS site use page convention name/number.
             if page._num is not None:
                 assert page_cnt == int(page._num), (
-                    'Page number %s not recognised as page %s.'
-                    % (page_cnt, title))
+                    'Page number {} not recognised as page {}.'
+                    .format(page_cnt, title))
 
             # Mapping: numbers <-> pages.
             self._page_from_numbers[page_cnt] = page
@@ -956,7 +960,7 @@ class IndexPage(pywikibot.Page):
     def num_pages(self) -> int:
         """Return total number of pages in Index.
 
-        @return: total number of pages in Index
+        :return: total number of pages in Index
         """
         return len(self._page_from_numbers)
 
@@ -967,14 +971,14 @@ class IndexPage(pywikibot.Page):
 
         Range is [start ... end], extremes included.
 
-        @param start: first page, defaults to 1
-        @param end: num_pages if end is None
-        @param filter_ql: filters quality levels
+        :param start: first page, defaults to 1
+        :param end: num_pages if end is None
+        :param filter_ql: filters quality levels
                           if None: all but 'Without Text'.
-        @type filter_ql: list of ints (corresponding to ql constants
+        :type filter_ql: list of ints (corresponding to ql constants
                          defined in ProofreadPage).
-        @param only_existing: yields only existing pages.
-        @param content: preload content.
+        :param only_existing: yields only existing pages.
+        :param content: preload content.
         """
         if end is None:
             end = self.num_pages
@@ -1010,8 +1014,8 @@ class IndexPage(pywikibot.Page):
 
         There is a 1-to-1 correspondence (each page has a label).
 
-        @param page: Page instance
-        @return: page label
+        :param page: Page instance
+        :return: page label
         """
         try:
             return self._labels_from_page[page]
@@ -1024,7 +1028,7 @@ class IndexPage(pywikibot.Page):
 
         There is a 1-to-1 correspondence (each page has a label).
 
-        @return: page label
+        :return: page label
         """
         try:
             return self._labels_from_page_number[page_number]
@@ -1051,7 +1055,7 @@ class IndexPage(pywikibot.Page):
         There is a 1-to-many correspondence (a label can be the same for
         several pages).
 
-        @return: set containing page numbers corresponding to page label.
+        :return: set containing page numbers corresponding to page label.
         """
         return self._get_from_label(self._page_numbers_from_label, label)
 
@@ -1062,7 +1066,7 @@ class IndexPage(pywikibot.Page):
         There is a 1-to-many correspondence (a label can be the same for
         several pages).
 
-        @return: set containing pages corresponding to page label.
+        :return: set containing pages corresponding to page label.
         """
         return self._get_from_label(self._pages_from_label, label)
 
@@ -1072,13 +1076,13 @@ class IndexPage(pywikibot.Page):
         try:
             return self._page_from_numbers[page_number]
         except KeyError:
-            raise KeyError('Invalid page number: %s.' % page_number)
+            raise KeyError('Invalid page number: {}.'.format(page_number))
 
     @check_if_cached
     def pages(self) -> list:
         """Return the list of pages in Index, sorted by page number.
 
-        @return: list of pages
+        :return: list of pages
         """
         return [self._page_from_numbers[i]
                 for i in range(1, self.num_pages + 1)]
@@ -1090,8 +1094,3 @@ class IndexPage(pywikibot.Page):
             return self._numbers_from_page[page]
         except KeyError:
             raise KeyError('Invalid page: {}.'.format(page))
-
-
-wrapper = ModuleDeprecationWrapper(__name__)
-wrapper._add_deprecated_attr('Soup', _bs4_soup, replacement_name='_bs4_soup',
-                             since='20181128')
