@@ -5,11 +5,12 @@
 # Distributed under the terms of the MIT license.
 #
 import json
-
 from contextlib import suppress
 from html.parser import HTMLParser
+from http import HTTPStatus
 from typing import Optional
 from urllib.parse import urljoin, urlparse
+
 from requests.exceptions import RequestException
 
 import pywikibot
@@ -32,10 +33,10 @@ class MWSite:
         """
         Initializer.
 
-        @raises pywikibot.exceptions.ServerError: a server error occurred
+        :raises pywikibot.exceptions.ServerError: a server error occurred
             while loading the site
-        @raises Timeout: a timeout occurred while loading the site
-        @raises RuntimeError: Version not found or version less than 1.23
+        :raises Timeout: a timeout occurred while loading the site
+        :raises RuntimeError: Version not found or version less than 1.23
         """
         if fromurl.endswith('$1'):
             fromurl = fromurl[:-2]
@@ -101,8 +102,8 @@ class MWSite:
               '&sifilteriw=local&format=json')
         iw = json.loads(response.text)
         if 'error' in iw:
-            raise RuntimeError('%s - %s' % (iw['error']['code'],
-                                            iw['error']['info']))
+            raise RuntimeError('{} - {}'.format(iw['error']['code'],
+                                                iw['error']['info']))
         return [wiki for wiki in iw['query']['interwikimap']
                 if 'language' in wiki]
 
@@ -272,12 +273,13 @@ class WikiHTMLPageParser(HTMLParser):
 
 
 def check_response(response):
-    """Raise ServerError if the response indicates a server error."""
-    if response.status_code == 503:
-        raise ServerError('Service Unavailable')
-    elif response.status_code == 502:
-        raise ServerError('Bad Gateway')
-    elif response.status_code == 500:
-        raise ServerError('Internal Server Error')
-    elif response.status_code == 200 and SERVER_DB_ERROR_MSG in response.text:
+    """Raise ServerError if the response indicates a server error.
+
+    *New in version 3.0.*
+    """
+    if response.status_code >= HTTPStatus.INTERNAL_SERVER_ERROR:
+        raise ServerError(HTTPStatus(response.status_code).phrase)
+
+    if response.status_code == HTTPStatus.OK \
+       and SERVER_DB_ERROR_MSG in response.text:
         raise ServerError('Server cannot access the database')
