@@ -4,19 +4,25 @@
 Do not import classes directly from here but from specialbots.
 """
 #
-# (C) Pywikibot team, 2003-2020
+# (C) Pywikibot team, 2003-2021
 #
 # Distributed under the terms of the MIT license.
 #
 from pywikibot.bot import (
-    AlwaysChoice, AutomaticTWSummaryBot, ChoiceException, ExistingPageBot,
-    InteractiveReplace, NoRedirectPageBot, UnhandledAnswer,
+    AlwaysChoice,
+    AutomaticTWSummaryBot,
+    ChoiceException,
+    ExistingPageBot,
+    InteractiveReplace,
+    NoRedirectPageBot,
 )
 from pywikibot.editor import TextEditor
+from pywikibot.bot_choice import UnhandledAnswer
 from pywikibot.textlib import replace_links
+from pywikibot.tools import ModuleDeprecationWrapper
 
 
-class EditReplacement(ChoiceException, UnhandledAnswer):
+class EditReplacementError(ChoiceException, UnhandledAnswer):
 
     """The text should be edited and replacement should be restarted."""
 
@@ -38,7 +44,7 @@ class InteractiveUnlink(InteractiveReplace):
         self._always.always = bot.opt.always
         self.additional_choices = [
             AlwaysChoice(self, 'unlink all on page', 'p'),
-            self._always, EditReplacement()]
+            self._always, EditReplacementError()]
         self._bot = bot
         self.context = 100
         self.context_change = 100
@@ -74,7 +80,7 @@ class BaseUnlinkBot(ExistingPageBot, NoRedirectPageBot, AutomaticTWSummaryBot):
             unlink_callback = self._create_callback()
             try:
                 text = replace_links(text, unlink_callback, target_page.site)
-            except EditReplacement:
+            except EditReplacementError:
                 new_text = TextEditor().edit(
                     unlink_callback.current_text,
                     jumpIndex=unlink_callback.current_range[0])
@@ -87,3 +93,12 @@ class BaseUnlinkBot(ExistingPageBot, NoRedirectPageBot, AutomaticTWSummaryBot):
                 break
 
         self.put_current(text)
+
+
+EditReplacement = EditReplacementError
+
+wrapper = ModuleDeprecationWrapper(__name__)
+wrapper.add_deprecated_attr(
+    'EditReplacement',
+    replacement_name='EditReplacementError',
+    since='20210423')
