@@ -4,28 +4,27 @@
 Do not import classes directly from here but from specialbots.
 """
 #
-# (C) Pywikibot team, 2003-2020
+# (C) Pywikibot team, 2003-2021
 #
 # Distributed under the terms of the MIT license.
 #
 import os
-import requests
 import tempfile
-
 from contextlib import suppress
+from http import HTTPStatus
 from pathlib import Path
 from typing import Optional, Union
 from urllib.parse import urlparse
 
+import requests
+
 import pywikibot
 import pywikibot.comms.http as http
 import pywikibot.data.api
-
-from pywikibot.backports import List
 from pywikibot import config
+from pywikibot.backports import List
 from pywikibot.bot import BaseBot, QuitKeyboardInterrupt
-from pywikibot.data.api import APIError
-from pywikibot.exceptions import FatalServerError
+from pywikibot.exceptions import APIError, FatalServerError, NoPageError
 from pywikibot.tools import deprecated_args
 from pywikibot.tools.formatter import color_format
 
@@ -48,40 +47,53 @@ class UploadRobot(BaseBot):
                  target_site=None,
                  aborts: Union[bool, list, None] = None,
                  chunk_size: int = 0,
+                 asynchronous: bool = False,
                  summary: Optional[str] = None,
-                 filename_prefix: Optional[str] = None, **kwargs):
+                 filename_prefix: Optional[str] = None,
+                 force_if_shared: bool = False,
+                 **kwargs):
         """Initializer.
 
-        @param url: path to url or local file, or list of urls or paths
+        *Changed in version 6.2:* asynchronous upload is used if
+        *asynchronous* parameter is set.
+
+        *New in version 6.4:* force_if_shared parameter.
+
+        :param url: path to url or local file, or list of urls or paths
             to local files.
-        @param description: Description of file for its page. If multiple files
+        :param description: Description of file for its page. If multiple files
             are uploading the same description is used for every file.
-        @type description: str
-        @param use_filename: Specify title of the file's page. If multiple
+        :type description: str
+        :param use_filename: Specify title of the file's page. If multiple
             files are uploading it asks to change the name for second, third,
             etc. files, otherwise the last file will overwrite the other.
-        @param keep_filename: Set to True to keep original names of urls and
+        :param keep_filename: Set to True to keep original names of urls and
             files, otherwise it will ask to enter a name for each file.
-        @param summary: Summary of the upload
-        @param verify_description: Set to True to proofread the description.
-        @param ignore_warning: Set this to True to upload even if another file
+        :param summary: Summary of the upload
+        :param verify_description: Set to True to proofread the description.
+        :param ignore_warning: Set this to True to upload even if another file
             would be overwritten or another mistake would be risked. Set it to
             an array of warning codes to selectively ignore specific warnings.
-        @param target_site: Set the site to upload to. If target site is not
+        :param target_site: Set the site to upload to. If target site is not
             given it's taken from user-config.py.
-        @type target_site: object
-        @param aborts: List of the warning types to abort upload on. Set to
+        :type target_site: object
+        :param aborts: List of the warning types to abort upload on. Set to
             True to abort on any warning.
-        @param chunk_size: Upload the file in chunks (more overhead, but
+        :param chunk_size: Upload the file in chunks (more overhead, but
             restartable) specified in bytes. If no value is specified the file
             will be uploaded as whole.
-        @param filename_prefix: Specify prefix for the title of every
+        :param asynchronous: Make potentially large file operations
+            asynchronous on the server side when possible.
+        :param filename_prefix: Specify prefix for the title of every
             file's page.
-        @keyword always: Disables any input, requires that either
+        :param force_if_shared: Upload the file even if it's currently
+            shared to the target site (e.g. when moving from Commons to another
+            wiki)
+        :keyword always: Disables any input, requires that either
             ignore_warning or aborts are set to True and that the
             description is also set. It overwrites verify_description to
             False and keep_filename to True.
-        @type always: bool
+        :type always: bool
         """
         super().__init__(**kwargs)
         if self.opt.always:
@@ -102,8 +114,10 @@ class UploadRobot(BaseBot):
         self.ignore_warning = ignore_warning
         self.aborts = aborts or []
         self.chunk_size = chunk_size
+        self.asynchronous = asynchronous
         self.summary = summary
         self.filename_prefix = filename_prefix
+        self.force_if_shared = force_if_shared
 
         if config.upload_to_commons:
             default_site = pywikibot.Site('commons:commons')
@@ -151,17 +165,17 @@ class UploadRobot(BaseBot):
                 # raised from connection lost during response.iter_content()
                 except requests.ConnectionError:
                     fd.flush()
-                    pywikibot.output(
-                        'Connection closed at byte %s' % path.stat().st_size)
+                    pywikibot.output('Connection closed at byte {}'
+                                     .format(path.stat().st_size))
                 # raised from response.raise_for_status()
                 except requests.HTTPError as e:
                     # exit criteria if size is not available
                     # error on last iteration is OK, we're requesting
                     #    {'Range': 'bytes=file_len-'}
-                    if response.status_code == 416 and path.stat().st_size:
+                    err = HTTPStatus.REQUESTED_RANGE_NOT_SATISFIABLE
+                    if response.status_code == err and path.stat().st_size:
                         break
-                    else:
-                        raise FatalServerError(str(e)) from e
+                    raise FatalServerError(str(e)) from e
 
             if size and size == path.stat().st_size:
                 break
@@ -178,8 +192,8 @@ class UploadRobot(BaseBot):
     def _handle_warning(self, warning: str) -> Optional[bool]:
         """Return whether the warning cause an abort or be ignored.
 
-        @param warning: The warning name
-        @return: False if this warning should cause an abort, True if it should
+        :param warning: The warning name
+        :return: False if this warning should cause an abort, True if it should
             be ignored or None if this warning has no default handler.
         """
         if self.aborts is not True:
@@ -203,7 +217,7 @@ class UploadRobot(BaseBot):
             if this_answer is False:
                 answer = False
                 break
-            elif this_answer is None:
+            if this_answer is None:
                 answer = None
         if answer is None:
             answer = pywikibot.input_yn('Do you want to ignore?',
@@ -225,8 +239,8 @@ class UploadRobot(BaseBot):
             filename = self.filename_prefix + filename
         if not self.keep_filename:
             pywikibot.output(
-                'The filename on the target wiki will default to: %s'
-                % filename)
+                '\nThe filename on the target wiki will default to: {}\n'
+                .format(filename))
             assert not self.opt.always
             newfn = pywikibot.input(
                 'Enter a better name, or press enter to accept:')
@@ -262,19 +276,19 @@ class UploadRobot(BaseBot):
             if invalid:
                 c = ''.join(invalid)
                 pywikibot.output(
-                    'Invalid character(s): %s. Please try again' % c)
+                    'Invalid character(s): {}. Please try again'.format(c))
                 continue
 
             if allowed_formats and ext not in allowed_formats:
                 if self.opt.always:
                     pywikibot.output('File format is not one of '
-                                     '[{0}]'.format(' '.join(allowed_formats)))
+                                     '[{}]'.format(' '.join(allowed_formats)))
                     continue
 
                 if not pywikibot.input_yn(
-                        'File format is not one of [%s], but %s. Continue?'
-                        % (' '.join(allowed_formats), ext),
-                        default=False, automatic_quit=False):
+                        'File format is not one of [{}], but {!r}. Continue?'
+                        .format(' '.join(allowed_formats), ext),
+                        default=False):
                     continue
 
             potential_file_page = pywikibot.FilePage(self.target_site,
@@ -289,22 +303,22 @@ class UploadRobot(BaseBot):
                 if potential_file_page.has_permission():
                     if overwrite is None:
                         overwrite = not pywikibot.input_yn(
-                            'File with name %s already exists. '
+                            'File with name {} already exists. '
                             'Would you like to change the name? '
                             '(Otherwise file will be overwritten.)'
-                            % filename, default=True,
+                            .format(filename), default=True,
                             automatic_quit=False)
                     if not overwrite:
                         continue
-                    else:
-                        break
+                    break
 
                 pywikibot.output('File with name {} already exists and '
                                  'cannot be overwritten.'.format(filename))
                 continue
 
-            with suppress(pywikibot.NoPage):
-                if potential_file_page.file_is_shared():
+            with suppress(NoPageError):
+                if (not self.force_if_shared
+                        and potential_file_page.file_is_shared()):
                     pywikibot.output(
                         'File with name {} already exists in shared '
                         'repository and cannot be overwritten.'
@@ -315,8 +329,8 @@ class UploadRobot(BaseBot):
         # A proper description for the submission.
         # Empty descriptions are not accepted.
         if self.description:
-            pywikibot.output('The suggested description is:\n%s'
-                             % self.description)
+            pywikibot.output('The suggested description is:\n{}'
+                             .format(self.description))
 
         while not self.description or self.verify_description:
             if not self.description:
@@ -360,7 +374,7 @@ class UploadRobot(BaseBot):
         """
         Determine if the warning message should be ignored.
 
-        @param warn_code: The warning message
+        :param warn_code: The warning message
         """
         return self.ignore_warning is True or warn_code in self.ignore_warning
 
@@ -368,7 +382,7 @@ class UploadRobot(BaseBot):
         """
         Upload the image at file_url to the target wiki.
 
-        @see: U{https://www.mediawiki.org/wiki/API:Upload}
+        :see: https://www.mediawiki.org/wiki/API:Upload
 
         Return the filename that was used to upload the image.
         If the upload fails, ask the user whether to try again or not.
@@ -382,7 +396,7 @@ class UploadRobot(BaseBot):
         imagepage = pywikibot.FilePage(site, filename)  # normalizes filename
         imagepage.text = self.description
 
-        pywikibot.output('Uploading file to {0}...'.format(site))
+        pywikibot.output('Uploading file to {}...'.format(site))
 
         ignore_warnings = self.ignore_warning is True or self._handle_warnings
         if '://' in file_url and not site.has_right('upload_by_url'):
@@ -396,12 +410,13 @@ class UploadRobot(BaseBot):
                                        ignore_warnings=ignore_warnings,
                                        chunk_size=self.chunk_size,
                                        _file_key=_file_key, _offset=_offset,
+                                       asynchronous=self.asynchronous,
                                        comment=self.summary)
         except APIError as error:
             if error.code == 'uploaddisabled':
                 pywikibot.error(
-                    'Upload error: Local file uploads are disabled on %s.'
-                    % site)
+                    'Upload error: Local file uploads are disabled on {}.'
+                    .format(site))
             else:
                 pywikibot.error('Upload error: ', exc_info=True)
         except Exception:
@@ -409,7 +424,7 @@ class UploadRobot(BaseBot):
         else:
             if success:
                 # No warning, upload complete.
-                pywikibot.output('Upload of %s successful.' % filename)
+                pywikibot.output('Upload of {} successful.'.format(filename))
                 self._save_counter += 1
                 return filename  # data['filename']
             pywikibot.output('Upload aborted.')
@@ -443,13 +458,13 @@ class UploadRobot(BaseBot):
                 self.upload_file(file_url)
                 self._treat_counter += 1
         except QuitKeyboardInterrupt:
-            pywikibot.output('\nUser quit %s bot run...' %
-                             self.__class__.__name__)
+            pywikibot.output('\nUser quit {} bot run...'
+                             .format(self.__class__.__name__))
         except KeyboardInterrupt:
             if config.verbose_output:
                 raise
-            else:
-                pywikibot.output('\nKeyboardInterrupt during %s bot run...' %
-                                 self.__class__.__name__)
+
+            pywikibot.output('\nKeyboardInterrupt during {} bot run...'
+                             .format(self.__class__.__name__))
         finally:
             self.exit()
