@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""Helper function fo MediaWiki title-cased forms."""
+"""Helper function which holds data from unicodedata library."""
 #
 # (C) Pywikibot team, 2018-2020
 #
@@ -266,3 +265,45 @@ _first_upper_exception_dict = {
 
 
 _first_upper_exception = _first_upper_exception_dict.get
+
+
+# All characters in the Cf category in a static list. When testing each Unicode
+# codepoint it takes longer especially when working with UCS2. The lists also
+# differ between Python versions which can be avoided by this static list.
+#
+# This frozenset was created using Python 3.9 (Unicode version 13.0.0):
+# list(c for c in (chr(i) for i in range(sys.maxunicode))
+#      if unicodedata.category(c) == 'Cf')
+_category_cf = frozenset([
+    '\xad',
+    '\u0600', '\u0601', '\u0602', '\u0603', '\u0604', '\u0605', '\u061c',
+    '\u06dd', '\u070f', '\u08e2', '\u180e', '\u200b', '\u200c', '\u200d',
+    '\u200e', '\u200f', '\u202a', '\u202b', '\u202c', '\u202d', '\u202e',
+    '\u2060', '\u2061', '\u2062', '\u2063', '\u2064', '\u2066', '\u2067',
+    '\u2068', '\u2069', '\u206a', '\u206b', '\u206c', '\u206d', '\u206e',
+    '\u206f', '\ufeff', '\ufff9', '\ufffa', '\ufffb',
+    '\U000110bd', '\U000110cd', '\U00013430', '\U00013431', '\U00013432',
+    '\U00013433', '\U00013434', '\U00013435', '\U00013436', '\U00013437',
+    '\U00013438', '\U0001bca0', '\U0001bca1', '\U0001bca2', '\U0001bca3',
+    '\U0001d173', '\U0001d174', '\U0001d175', '\U0001d176', '\U0001d177',
+    '\U0001d178', '\U0001d179', '\U0001d17a', '\U000e0001', '\U000e0020',
+    '\U000e0021', '\U000e0022', '\U000e0023', '\U000e0024', '\U000e0025',
+    '\U000e0026', '\U000e0027', '\U000e0028', '\U000e0029', '\U000e002a',
+    '\U000e002b', '\U000e002c', '\U000e002d', '\U000e002e', '\U000e002f',
+    '\U000e0030', '\U000e0031', '\U000e0032', '\U000e0033', '\U000e0034',
+    '\U000e0035', '\U000e0036', '\U000e0037', '\U000e0038', '\U000e0039',
+    '\U000e003a', '\U000e003b', '\U000e003c', '\U000e003d', '\U000e003e',
+    '\U000e003f', '\U000e0040', '\U000e0041', '\U000e0042', '\U000e0043',
+    '\U000e0044', '\U000e0045', '\U000e0046', '\U000e0047', '\U000e0048',
+    '\U000e0049', '\U000e004a', '\U000e004b', '\U000e004c', '\U000e004d',
+    '\U000e004e', '\U000e004f', '\U000e0050', '\U000e0051', '\U000e0052',
+    '\U000e0053', '\U000e0054', '\U000e0055', '\U000e0056', '\U000e0057',
+    '\U000e0058', '\U000e0059', '\U000e005a', '\U000e005b', '\U000e005c',
+    '\U000e005d', '\U000e005e', '\U000e005f', '\U000e0060', '\U000e0061',
+    '\U000e0062', '\U000e0063', '\U000e0064', '\U000e0065', '\U000e0066',
+    '\U000e0067', '\U000e0068', '\U000e0069', '\U000e006a', '\U000e006b',
+    '\U000e006c', '\U000e006d', '\U000e006e', '\U000e006f', '\U000e0070',
+    '\U000e0071', '\U000e0072', '\U000e0073', '\U000e0074', '\U000e0075',
+    '\U000e0076', '\U000e0077', '\U000e0078', '\U000e0079', '\U000e007a',
+    '\U000e007b', '\U000e007c', '\U000e007d', '\U000e007e', '\U000e007f',
+])
