@@ -8,11 +8,9 @@
 import os
 import re
 import subprocess
-
 from collections import Counter
 
 import pywikibot
-
 from pywikibot.tools import deprecated_args
 
 
@@ -20,13 +18,13 @@ def _call_cmd(args, lib='djvulibre') -> tuple:
     """
     Tiny wrapper around subprocess.Popen().
 
-    @param args: same as Popen()
-    @type args: str or typing.Sequence[string]
+    :param args: same as Popen()
+    :type args: str or typing.Sequence[string]
 
-    @param lib: library to be logged in logging messages
-    @type lib: str
+    :param lib: library to be logged in logging messages
+    :type lib: str
 
-    @return: returns a tuple (res, stdoutdata), where
+    :return: returns a tuple (res, stdoutdata), where
         res is True if dp.returncode != 0 else False
     """
     if not isinstance(args, str):
@@ -39,11 +37,11 @@ def _call_cmd(args, lib='djvulibre') -> tuple:
     stdoutdata, stderrdata = dp.communicate()
 
     if dp.returncode != 0:
-        pywikibot.error('{0} error; {1}'.format(lib, cmd))
-        pywikibot.error('{0}'.format(stderrdata))
+        pywikibot.error('{} error; {}'.format(lib, cmd))
+        pywikibot.error(str(stderrdata))
         return (False, stdoutdata)
 
-    pywikibot.log('SUCCESS: {0} (PID: {1})'.format(cmd, dp.pid))
+    pywikibot.log('SUCCESS: {} (PID: {})'.format(cmd, dp.pid))
 
     return (True, stdoutdata)
 
@@ -65,7 +63,7 @@ class DjVuFile:
         """
         Initializer.
 
-        @param file: filename (including path) to djvu file
+        :param file: filename (including path) to djvu file
         """
         self._filename = file
         filename = os.path.expanduser(file)
@@ -83,9 +81,9 @@ class DjVuFile:
 
     def __repr__(self) -> str:
         """Return a more complete string representation."""
-        return str("{0}.{1}('{2}')").format(self.__module__,
-                                            self.__class__.__name__,
-                                            self._filename)
+        return str("{}.{}('{}')").format(self.__module__,
+                                         self.__class__.__name__,
+                                         self._filename)
 
     def __str__(self) -> str:
         """Return a string representation."""
@@ -107,14 +105,15 @@ class DjVuFile:
     def check_page_number(fn):
         """Decorator to check if page number is valid.
 
-        @raises ValueError
+        :raises ValueError
         """
         def wrapper(obj, *args, **kwargs):
             n = args[0]
             force = kwargs.get('force', False)
             if not (1 <= n <= obj.number_of_images(force=force)):
-                raise ValueError('Page %d not in file %s [%d-%d]'
-                                 % (n, obj.file, n, obj.number_of_images()))
+                raise ValueError('Page {} not in file {} [{}-{}]'
+                                 .format(int(n), obj.file, int(n),
+                                         int(obj.number_of_images())))
             _res = fn(obj, *args, **kwargs)
             return _res
         return wrapper
@@ -124,8 +123,8 @@ class DjVuFile:
         """
         Return the number of images in the djvu file.
 
-        @param force: if True, refresh the cached data
-        @type force: bool
+        :param force: if True, refresh the cached data
+        :type force: bool
         """
         if not hasattr(self, '_page_count'):
             res, stdoutdata = _call_cmd(['djvused', '-e', 'n', self.file])
@@ -139,8 +138,8 @@ class DjVuFile:
         """
         Return a tuple (id, (size, dpi)) for page n of djvu file.
 
-        @param force: if True, refresh the cached data
-        @type force: bool
+        :param force: if True, refresh the cached data
+        :type force: bool
         """
         if not hasattr(self, '_page_info') or force:
             self._get_page_info(force=force)
@@ -151,8 +150,8 @@ class DjVuFile:
         """
         Return a dict of tuples (id, (size, dpi)) for all pages of djvu file.
 
-        @param force: if True, refresh the cached data
-        @type force: bool
+        :param force: if True, refresh the cached data
+        :type force: bool
         """
         if not hasattr(self, '_page_info'):
             self._page_info = {}
@@ -199,8 +198,8 @@ class DjVuFile:
         """
         Test if the djvu file has a text-layer.
 
-        @param force: if True, refresh the cached data
-        @type force: bool
+        :param force: if True, refresh the cached data
+        :type force: bool
         """
         if not hasattr(self, '_has_text'):
             self._get_page_info(force=force)
@@ -228,12 +227,14 @@ class DjVuFile:
         """
         Get page n for djvu file.
 
-        @param force: if True, refresh the cached data
-        @type force: bool
+        :param force: if True, refresh the cached data
+        :type force: bool
         """
         if not self.has_text(force=force):
-            raise ValueError('Djvu file %s has no text layer.' % self.file)
-        res, stdoutdata = _call_cmd(['djvutxt', '--page=%d' % n, self.file])
+            raise ValueError('Djvu file {} has no text layer.'
+                             .format(self.file))
+        res, stdoutdata = _call_cmd(['djvutxt', '--page={}'.format(int(n)),
+                                     self.file])
         if not res:
             return False
         return self._remove_control_chars(stdoutdata)
