@@ -2,19 +2,20 @@
 A window with a textfield where the user can edit.
 
 Useful for editing the contents of an article.
+
+*New in version 6.1:* Python 3.6 or highter is required.
 """
 #
-# (C) Pywikibot team, 2003-2020
+# (C) Pywikibot team, 2003-2021
 #
 # Distributed under the terms of the MIT license.
 #
 import tkinter
-from tkinter.scrolledtext import ScrolledText
 from tkinter import simpledialog as tkSimpleDialog
+from tkinter.scrolledtext import ScrolledText
 from typing import Optional
 
 import pywikibot
-
 from pywikibot import __url__
 from pywikibot.backports import Tuple
 from pywikibot.tools import PYTHON_VERSION
@@ -22,15 +23,13 @@ from pywikibot.tools import PYTHON_VERSION
 
 # T164163: Fix idlelib import in Python 3.6
 if PYTHON_VERSION >= (3, 6):
-    from idlelib import (
-        search as SearchDialog,
-        replace as ReplaceDialog,
-    )
+    from idlelib import replace as ReplaceDialog
+    from idlelib import search as SearchDialog
     from idlelib.config import idleConf
     from idlelib.configdialog import ConfigDialog
     from idlelib.multicall import MultiCallCreator
 else:
-    from idlelib import SearchDialog, ReplaceDialog
+    from idlelib import ReplaceDialog, SearchDialog
     from idlelib.configDialog import ConfigDialog
     from idlelib.configHandler import idleConf
     from idlelib.MultiCall import MultiCallCreator
@@ -241,7 +240,7 @@ class TextEditor(ScrolledText):
                     if not idx:
                         break
                     # index right after the end of the occurrence
-                    lastidx = '%s+%dc' % (idx, len(s))
+                    lastidx = '{}+{}c'.format(idx, len(s))
                     # tag the whole occurrence (start included, stop excluded)
                     self.tag_add('found', idx, lastidx)
                     # prepare to search for next occurrence
@@ -269,7 +268,7 @@ class TextEditor(ScrolledText):
         if lineno <= 0:
             self.bell()
             return 'break'
-        self.mark_set('insert', '%d.0' % lineno)
+        self.mark_set('insert', '{}.0'.format(lineno))
         self.see('insert')
         return None
 
@@ -377,12 +376,12 @@ class EditBoxWindow(tkinter.Frame):
         """
         Provide user with editor to modify text.
 
-        @param text: the text to be edited
-        @param jumpIndex: position at which to put the caret
-        @param highlight: each occurrence of this substring will be highlighted
-        @return: the modified text, or None if the user didn't save the text
+        :param text: the text to be edited
+        :param jumpIndex: position at which to put the caret
+        :param highlight: each occurrence of this substring will be highlighted
+        :return: the modified text, or None if the user didn't save the text
             file in his text editor
-        @rtype: str or None
+        :rtype: str or None
         """
         self.text = None
         # put given text into our textarea
@@ -400,7 +399,7 @@ class EditBoxWindow(tkinter.Frame):
             column = jumpIndex - (text[:jumpIndex].rfind('\n') + 1)
             # don't know how to place the caret, but scrolling to the right
             # line should already be helpful.
-            self.editbox.see('%d.%d' % (line, column))
+            self.editbox.see('{}.{}'.format(line, column))
         # wait for user to push a button which will destroy (close) the window
         self.parent.mainloop()
         return self.text
@@ -499,8 +498,9 @@ class Tkdialog:
         """Initializer."""
         self.root = tkinter.Tk()
         # "%dx%d%+d%+d" % (width, height, xoffset, yoffset)
-        self.root.geometry('%ix%i+10-10' % (pywikibot.config.tkhorsize,
-                                            pywikibot.config.tkvertsize))
+        self.root.geometry('{}x{}+10-10'
+                           .format(int(pywikibot.config.tkhorsize),
+                                   int(pywikibot.config.tkvertsize)))
 
         self.root.title(filename)
         self.photo_description = photo_description
@@ -560,12 +560,21 @@ class Tkdialog:
 
     def get_image(self, photo, width, height):
         """Take the BytesIO object and build an imageTK thumbnail."""
+        if PYTHON_VERSION < (3, 6):
+            # vulnerability found in Pillow<8.1.1
+            from sys import version
+            raise RuntimeError(
+                'This script requires Python 3.6+ for GUI support.\n'
+                '{version} is not supported. Please update your Python.'
+                .format(version=version.split(maxsplit=1)[0])
+            )
+
         try:
             from PIL import Image, ImageTk
         except ImportError:
             pywikibot.warning('This script requires ImageTk from the'
                               'Python Imaging Library (PIL).\n'
-                              'See: {0}/flickrripper.py'.format(__url__))
+                              'See: {}/flickrripper.py'.format(__url__))
             raise
 
         image = Image.open(photo)
@@ -587,7 +596,7 @@ class Tkdialog:
     def show_dialog(self) -> Tuple[str, str, bool]:
         """Activate the dialog.
 
-        @return: new description, name, and if the image is skipped
+        :return: new description, name, and if the image is skipped
         """
         self.root.mainloop()
         return self.photo_description, self.filename, self.skip
