@@ -11,44 +11,39 @@ import pathlib
 import socket
 import subprocess
 import sys
+import sysconfig
 import time
 import xml.dom.minidom
-
 from contextlib import closing, suppress
-from distutils.sysconfig import get_python_lib
 from importlib import import_module
 from io import BytesIO
 from typing import Optional
 from warnings import warn
 
 import pywikibot
-
+from pywikibot import config
 from pywikibot.backports import cache
 from pywikibot.comms.http import fetch
-from pywikibot import config2 as config
-from pywikibot.tools import deprecated
+from pywikibot.exceptions import VersionParseError
+from pywikibot.tools import ModuleDeprecationWrapper, deprecated
 
 
 _logger = 'version'
 
 
-class ParseError(Exception):
-
-    """Parsing went wrong."""
-
-
 def _get_program_dir():
     _program_dir = os.path.normpath(
         os.path.split(os.path.dirname(__file__))[0])
     return _program_dir
 
 
-def get_toolforge_hostname():
+def get_toolforge_hostname() -> Optional[str]:
     """Get hostname of the current Toolforge host.
 
-    @return: The hostname of the currently running host,
+    *New in version 3.0.*
+
+    :return: The hostname of the currently running host,
              if it is in Wikimedia Toolforge; otherwise return None.
-    @rtype: str or None
     """
     if socket.getfqdn().endswith('.tools.eqiad.wmflabs'):
         return socket.gethostname()
@@ -58,7 +53,7 @@ def get_toolforge_hostname():
 def getversion(online: bool = True) -> str:
     """Return a pywikibot version string.
 
-    @param online: Include information obtained online
+    :param online: Include information obtained online
     """
     branches = {
         'master': 'branches/master',
@@ -87,12 +82,12 @@ def getversion(online: bool = True) -> str:
 def getversiondict():
     """Get version info for the package.
 
-    @return:
+    :return:
         - tag (name for the repository),
         - rev (current revision identifier),
         - date (date of current revision),
         - hash (git hash for the current revision)
-    @rtype: C{dict} of four C{str}
+    :rtype: ``dict`` of four ``str``
     """
     _program_dir = _get_program_dir()
     exceptions = {}
@@ -117,7 +112,7 @@ def getversiondict():
              .format(exceptions), UserWarning)
         exceptions = None
 
-    # git and svn can silently fail, as it may be a nightly.
+    # Git and SVN can silently fail, as it may be a nightly.
     if exceptions:
         pywikibot.debug('version algorithm exceptions:\n{!r}'
                         .format(exceptions), _logger)
@@ -136,12 +131,12 @@ def getversiondict():
 def svn_rev_info(path):  # pragma: no cover
     """Fetch information about the current revision of a Subversion checkout.
 
-    @param path: directory of the Subversion checkout
-    @return:
+    :param path: directory of the Subversion checkout
+    :return:
         - tag (name for the repository),
         - rev (current Subversion revision identifier),
         - date (date of current revision),
-    @rtype: C{tuple} of two C{str} and a C{time.struct_time}
+    :rtype: ``tuple`` of two ``str`` and a ``time.struct_time``
     """
     if not os.path.isdir(os.path.join(path, '.svn')):
         path = os.path.join(path, '..')
@@ -158,7 +153,7 @@ def svn_rev_info(path):  # pragma: no cover
                 t = tag.split('://', 1)
                 t[1] = t[1].replace('svn.wikimedia.org/svnroot/pywikipedia/',
                                     '')
-                tag = '[{0}] {1}'.format(*t)
+                tag = '[{}] {}'.format(*t)
                 for _ in range(4):
                     entries.readline()
                 date = time.strptime(entries.readline()[:19],
@@ -187,9 +182,9 @@ order by revision desc, changed_date desc""")
 def github_svn_rev2hash(tag: str, rev):  # pragma: no cover
     """Convert a Subversion revision to a Git hash using Github.
 
-    @param tag: name of the Subversion repo on Github
-    @param rev: Subversion revision identifier
-    @return: the git hash
+    :param tag: name of the Subversion repo on Github
+    :param rev: Subversion revision identifier
+    :return: the git hash
     """
     uri = 'https://github.com/wikimedia/{}/!svn/vcc/default'.format(tag)
     request = fetch(uri, method='PROPFIND',
@@ -207,13 +202,13 @@ def github_svn_rev2hash(tag: str, rev):  # pragma: no cover
 def getversion_svn(path=None):  # pragma: no cover
     """Get version info for a Subversion checkout.
 
-    @param path: directory of the Subversion checkout
-    @return:
+    :param path: directory of the Subversion checkout
+    :return:
         - tag (name for the repository),
         - rev (current Subversion revision identifier),
         - date (date of current revision),
         - hash (git hash for the Subversion revision)
-    @rtype: C{tuple} of three C{str} and a C{time.struct_time}
+    :rtype: ``tuple`` of three ``str`` and a ``time.struct_time``
     """
     _program_dir = path or _get_program_dir()
     tag, rev, date = svn_rev_info(_program_dir)
@@ -226,29 +221,29 @@ def getversion_svn(path=None):  # pragma: no cover
         for i in range(len(date) - 1):
             assert date[i] == date2[i], 'Date of version is not consistent'
 
-    rev = 's%s' % rev
+    rev = 's{}'.format(rev)
     if (not date or not tag or not rev) and not path:
-        raise ParseError
+        raise VersionParseError
     return (tag, rev, date, hsh)
 
 
 def getversion_git(path=None):
     """Get version info for a Git clone.
 
-    @param path: directory of the Git checkout
-    @return:
+    :param path: directory of the Git checkout
+    :return:
         - tag (name for the repository),
         - rev (current revision identifier),
         - date (date of current revision),
         - hash (git hash for the current revision)
-    @rtype: C{tuple} of three C{str} and a C{time.struct_time}
+    :rtype: ``tuple`` of three ``str`` and a ``time.struct_time``
     """
     _program_dir = path or _get_program_dir()
     cmd = 'git'
     try:
         subprocess.Popen([cmd], stdout=subprocess.PIPE).communicate()
     except OSError:
-        # some windows git versions provide git.cmd instead of git.exe
+        # some Windows git versions provide git.cmd instead of git.exe
         cmd = 'git.cmd'
 
     with open(os.path.join(_program_dir, '.git/config'), 'r') as f:
@@ -264,7 +259,7 @@ def getversion_git(path=None):
         e = tag.find('\n', s)
         tag = tag[(s + 6):e]
         t = tag.strip().split('/')
-        tag = '[%s] %s' % (t[0][:-1], '-'.join(t[3:]))
+        tag = '[{}] {}'.format(t[0][:-1], '-'.join(t[3:]))
     dp = subprocess.Popen([cmd, '--no-pager',
                            'log', '-1',
                            '--pretty=format:"%ad|%an|%h|%H|%d"',
@@ -280,23 +275,23 @@ def getversion_git(path=None):
                           cwd=_program_dir,
                           stdout=subprocess.PIPE)
     rev, stderr = dp.communicate()
-    rev = 'g%s' % len(rev.splitlines())
+    rev = 'g{}'.format(len(rev.splitlines()))
     hsh = info[3]  # also stored in '.git/refs/heads/master'
     if (not date or not tag or not rev) and not path:
-        raise ParseError
+        raise VersionParseError
     return (tag, rev, date, hsh)
 
 
 def getversion_nightly(path=None):  # pragma: no cover
     """Get version info for a nightly release.
 
-    @param path: directory of the uncompressed nightly.
-    @return:
+    :param path: directory of the uncompressed nightly.
+    :return:
         - tag (name for the repository),
         - rev (current revision identifier),
         - date (date of current revision),
         - hash (git hash for the current revision)
-    @rtype: C{tuple} of three C{str} and a C{time.struct_time}
+    :rtype: ``tuple`` of three ``str`` and a ``time.struct_time``
     """
     if not path:
         path = _get_program_dir()
@@ -307,20 +302,20 @@ def getversion_nightly(path=None):  # pragma: no cover
     date = time.strptime(date[:19], '%Y-%m-%dT%H:%M:%S')
 
     if not date or not tag or not rev:
-        raise ParseError
+        raise VersionParseError
     return (tag, rev, date, hsh)
 
 
 def getversion_package(path=None):
     """Get version info for an installed package.
 
-    @param path: Unused argument
-    @return:
+    :param path: Unused argument
+    :return:
         - tag: 'pywikibot/__init__.py'
         - rev: '-1 (unknown)'
         - date (date the package was installed locally),
         - hash (git hash for the current revision of 'pywikibot/__init__.py')
-    @rtype: C{tuple} of four C{str}
+    :rtype: ``tuple`` of four ``str``
     """
     hsh = ''
     date = get_module_mtime(pywikibot).timetuple()
@@ -334,6 +329,7 @@ def getversion_package(path=None):
 def getversion_onlinerepo(path='branches/master'):
     """Retrieve current framework git hash from Gerrit."""
     from pywikibot.comms import http
+
     # Gerrit API responses include )]}' at the beginning,
     # make sure to strip it out
     buf = http.fetch(
@@ -343,7 +339,7 @@ def getversion_onlinerepo(path='branches/master'):
         hsh = json.loads(buf)['revision']
         return hsh
     except Exception as e:
-        raise ParseError(repr(e) + ' while parsing ' + repr(buf))
+        raise VersionParseError('{!r} while parsing {!r}'.format(e, buf))
 
 
 @deprecated('pywikibot.__version__', since='20201003')
@@ -351,9 +347,9 @@ def get_module_version(module) -> Optional[str]:  # pragma: no cover
     """
     Retrieve __version__ variable from an imported module.
 
-    @param module: The module instance.
-    @type module: module
-    @return: The version hash without the surrounding text. If not present
+    :param module: The module instance.
+    :type module: module
+    :return: The version hash without the surrounding text. If not present
         return None.
     """
     if hasattr(module, '__version__'):
@@ -369,9 +365,9 @@ def get_module_filename(module) -> Optional[str]:
     with py and another character the last character is discarded when the py
     file exist.
 
-    @param module: The module instance.
-    @type module: module
-    @return: The filename if it's a pywikibot module otherwise None.
+    :param module: The module instance.
+    :type module: module
+    :return: The filename if it's a pywikibot module otherwise None.
     """
     if hasattr(module, '__file__'):
         filename = module.__file__
@@ -388,10 +384,10 @@ def get_module_mtime(module):
     """
     Retrieve the modification time from an imported module.
 
-    @param module: The module instance.
-    @type module: module
-    @return: The modification time if it's a pywikibot module otherwise None.
-    @rtype: datetime or None
+    :param module: The module instance.
+    :type module: module
+    :return: The modification time if it's a pywikibot module otherwise None.
+    :rtype: datetime or None
     """
     filename = get_module_filename(module)
     if filename:
@@ -405,17 +401,17 @@ def package_versions(modules=None, builtins=False, standard_lib=None):
     When builtins or standard_lib are None, they will be included only
     if a version was found in the package.
 
-    @param modules: Modules to inspect
-    @type modules: list of strings
-    @param builtins: Include builtins
-    @type builtins: Boolean, or None for automatic selection
-    @param standard_lib: Include standard library packages
-    @type standard_lib: Boolean, or None for automatic selection
+    :param modules: Modules to inspect
+    :type modules: list of strings
+    :param builtins: Include builtins
+    :type builtins: Boolean, or None for automatic selection
+    :param standard_lib: Include standard library packages
+    :type standard_lib: Boolean, or None for automatic selection
     """
     if not modules:
         modules = sys.modules.keys()
 
-    std_lib_dir = pathlib.Path(get_python_lib(standard_lib=True))
+    std_lib_dir = pathlib.Path(sysconfig.get_paths()['stdlib'])
 
     root_packages = {key.split('.')[0] for key in modules}
 
@@ -503,3 +499,12 @@ def package_versions(modules=None, builtins=False, standard_lib=None):
             del data[name]
 
     return data
+
+
+ParseError = VersionParseError
+
+wrapper = ModuleDeprecationWrapper(__name__)
+wrapper.add_deprecated_attr(
+    'ParseError',
+    replacement_name='pywikibot.exceptions.VersionParseError',
+    since='20210423')
